function varargout = gui_ocean_toolbox(varargin)
% The main figure m-file for the Matlab OPeNDAP Ocean Toolbox.
%
% gui_ocean_toolbox
% h = gui_ocean_toolbox
%
% INPUT(S):
%
%   [none] -- 
%
% OUTPUT(S):
%
%   h -- (optional) handle to GUI figure.
%
% OPeNDAP Science Team
% Copyright 2007, 2008
% $Version 2.1.0$

%==========================================================================
% Christian Buckingham
%
% REVISION HISTORY:
% 2007/05/01 0.0.x created, ceb
% 2008/01/01 0.0.x removed dataset buttons, replaced with radiobuttons;
%            cleaned up code, ceb
% 2008/03/01 2.0.0 released
% 2008/06/15 2.0.1 adding more guis
%==========================================================================

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @gui_ocean_toolbox_OpeningFcn, ...
                   'gui_OutputFcn',  @gui_ocean_toolbox_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT

% --- Executes just before gui_ocean_toolbox is made visible.
function gui_ocean_toolbox_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to gui_ocean_toolbox (see VARARGIN)

% Define handles "openfigure" field.
if ~isfield(handles,'openfigure')
    handles.openfigure = 0; %set equal to zero on the first time.
end

% Talk to program back at remote data site.
% The concept behind this file was that it might talk to remote server
% (which is continually checking a series of databases) to determine which
% databases are working properly and which are not. The code here would
% then disable the databases that were not working properly.
load NetworkVerification.mat %loads working_database variable
% contents of this file:
% -- guihandlenames -- used to disable or "turn off" pushbuttons
% -- interface_directories -- used to determine which .csv files exist
% -- working_database -- used to determine working datasets/databases

% Save main function for other m-files.
% main_function = mfilename('fullpath');
% pname = main_function(1:end - length(mfilename));
% fname = 'pointertomainfunction.mat';
% save([pname,fname],'main_function');

% Check to see if loaddap in path.
% status = uiopendap_toolboxpath(2);
% status_loaddap = uiopendap_toolboxpath(1);
% if status_loaddap ~= 1
%     handle = warndlg('Pldatease download "loaddap" at www.opendap.org.',...
%              'Add "loaddap"');
%     uiwait(handle);
% %     children_handles = get(handle,'Children');
% %     h1 = get(children_handles(2),'Children'); %,'string','click here')
% %     url = 'http://www.opendap.org/download/index.html';
% %     op_makeurl(h1,url);
%     %disp(['Use "addloaddap" at a later date.'])
% end

% Set interface name.
filename = 'ocean_toolbox.m';
txt = ['NASA/REASoN Ocean Data Portal - '];
tmp1 = ['Matlab OPeNDAP Ocean Toolbox'];
tmp2 = '';
txt = [txt,tmp1];
if 0 %(~isdeployed)
    tmp2 = strrep(op_version('mfile',filename),'Version ','');
    txt = [txt,' (Ver ',tmp2,')'];
end
set(hObject,'Name',txt);

% Set text depending on version.
tmp2 = strrep(op_version('mfile',filename),'Version ','');
set(handles.text44,'string',['MATLAB OPeNDAP Ocean Toolbox ',tmp2])

% Set logos.
LogoSet(hObject, eventdata, handles)

% Set ToolTipString.
ToolTipSet(hObject, eventdata, handles)

% Create master database from individual databases.
filename = 'masterdatabase.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname)-length(mfilename));
    filename = [pname,filename];
end

if 1 %~exist(filename,'file')
    MakeDatabase(filename)
end

% Set text dealing with compiler.
txt = '';
if (isdeployed)
    txt = 'Compiled with MATLAB R2008a';
end
set(handles.text77,'string',txt);

% Disable some data sets.
set(handles.radiobutton6,'visible','off') %seawinds not operational
set(handles.pushbutton35,'visible','off') %ghrsst not operational
set(handles.pushbutton46,'visible','off') %ghrsst not operational
set(handles.pushbutton47,'visible','off') %ghrsst not operational

% Set logo button invisible.
set(handles.pushbutton49,'visible','off')

% Set dates.
DateSet(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = hObject;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% Update handles "openfigure" field.
handles.openfigure = 1;

% Choose default command line output for gui_ocean_toolbox
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes gui_ocean_toolbox wait for user response (see UIRESUME)
% uiwait(handles.figure1);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function ToolTipSet(hObject, eventdata, handles)
% This function sets the tooltips.
txt=['Currently support only satellite and model gridded data.'];
op_tooltipwrap(handles.checkbox21,txt,50);
op_tooltipwrap(handles.checkbox22,txt,50);

txt=['Parameters from Atmospheric Infrared Sounder (AIRS)'];
op_tooltipwrap(handles.radiobutton7,txt,50);

txt=['Sea Surface Temperature from Geostationary Operational Environmental Satellite (GOES) (Regional)'];
op_tooltipwrap(handles.radiobutton1,txt,50);

txt=['HYbrid Coordinate Ocean Model (HYCOM)'];
op_tooltipwrap(handles.radiobutton2,txt,50);

txt=['Sea Surface Temperature from Moderate Resolution ',...
     'Imaging Spectroradiometer (MODIS)'];
op_tooltipwrap(handles.radiobutton8,txt,50);

txt=['Objectively Analyzed Air-Sea Flux (OA Flux)'];
op_tooltipwrap(handles.radiobutton3,txt,50);

txt=['Sea Surface Temperature (1-km) from AVHRR ',...
     'Using Pathfinder Algorithm (Regional)'];
op_tooltipwrap(handles.radiobutton4,txt,50);

txt=['Sea Surface Temperature (4-km) from AVHRR ',...
     'Using Pathfinder Algorithm'];
op_tooltipwrap(handles.radiobutton5,txt,50);

txt=['10-m Surface Winds from QuikSCAT and ADEOS II Scatterometer'];
op_tooltipwrap(handles.radiobutton6,txt,50);

txt=['Ocean Color from CZCS, SeaWIFS, MODIS and Merged SeaWIFS-MODIS'];
op_tooltipwrap(handles.pushbutton39,txt,50);

txt=['AVISO Altimetry from TOPEX, Jason, ERS and Merged'];
op_tooltipwrap(handles.pushbutton44,txt,50);

txt=['Global High Resolution Sea Surface Temperature (GHRSST)'];
op_tooltipwrap(handles.pushbutton46,txt,50);

% txt=['The OPeNDAP Toolbox uses a tool to combine data from multiple days ',...
%      'or from multiple requests into a convenient multidimensional structure. The ',...
%      'following options control how the merging tool places data from the users ',...
%      'workspace into this multidimensional structure.'];
% op_tooltipwrap(handles.pushbutton16,txt,50);

% txt=['The graphical interfaces and their datasets can ',...
%      'be filtered by specifying a set of latitudes, ',...
%      'longitudes, dates of interest or topic. ',...
%      'Use this tool to narrow your datasets of interest.'];
%op_tooltipwrap(handles.pushbutton14,txt,50);

txt=['Dataset Documentation'];
op_tooltipwrap(handles.pushbutton28,txt,50);
op_tooltipwrap(handles.pushbutton29,txt,50);
op_tooltipwrap(handles.pushbutton30,txt,50);
op_tooltipwrap(handles.pushbutton31,txt,50);
op_tooltipwrap(handles.pushbutton32,txt,50);
op_tooltipwrap(handles.pushbutton33,txt,50);
op_tooltipwrap(handles.pushbutton34,txt,50);
op_tooltipwrap(handles.pushbutton35,txt,50);
op_tooltipwrap(handles.pushbutton40,txt,50);
op_tooltipwrap(handles.pushbutton45,txt,50);
op_tooltipwrap(handles.pushbutton47,txt,50);

txt=['year'];
op_tooltipwrap(handles.edit11,txt,50);
txt=['month'];
op_tooltipwrap(handles.edit12,txt,50);
txt=['day'];
op_tooltipwrap(handles.edit13,txt,50);

txt=['year'];
op_tooltipwrap(handles.edit14,txt,50);
txt=['month'];
op_tooltipwrap(handles.edit15,txt,50);
txt=['day'];
op_tooltipwrap(handles.edit16,txt,50);

txt=['starting latitude'];
op_tooltipwrap(handles.edit17,txt,50);
txt=['ending latitude'];
op_tooltipwrap(handles.edit18,txt,50);

txt=['starting longitude'];
op_tooltipwrap(handles.edit19,txt,50);
txt=['ending longitude'];
op_tooltipwrap(handles.edit20,txt,50);

txt=['Helpful documenation on how to use the software ...'];
op_tooltipwrap(handles.pushbutton41,txt,50);
txt=['support@opendap.org'];
op_tooltipwrap(handles.pushbutton19,txt,50);
%==========================================================================
% --- Outputs from this function are returned to the command line.
function varargout = gui_ocean_toolbox_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;

% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
get_airs

% --- Executes on button press in pushbutton2.
function pushbutton2_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
get_goes

% --- Executes on button press in pushbutton3.
function pushbutton3_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

get_hycom

% --- Executes on button press in pushbutton4.
function pushbutton4_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
get_modis

% --- Executes on button press in pushbutton5.
function pushbutton5_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
get_oaflux

% --- Executes on button press in pushbutton6.
function pushbutton6_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton6 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
get_pathfinder4km

% --- Executes on button press in pushbutton7.
function pushbutton7_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton7 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
get_seawinds

% --- Executes on button press in pushbutton10.
function pushbutton10_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton10 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
op_toolboxpath(2)

% --- Executes on button press in pushbutton11.
function pushbutton11_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton11 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

%op_toolboxpath(1)

function edit1_Callback(hObject, eventdata, handles)
% hObject    handle to edit1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1 as text
%        str2double(get(hObject,'String')) returns contents of edit1 as a double


% --- Executes during object creation, after setting all properties.
function edit1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit2_Callback(hObject, eventdata, handles)
% hObject    handle to edit2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit2 as text
%        str2double(get(hObject,'String')) returns contents of edit2 as a double


% --- Executes during object creation, after setting all properties.
function edit2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit3_Callback(hObject, eventdata, handles)
% hObject    handle to edit3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit3 as text
%        str2double(get(hObject,'String')) returns contents of edit3 as a double


% --- Executes during object creation, after setting all properties.
function edit3_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit4_Callback(hObject, eventdata, handles)
% hObject    handle to edit4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit4 as text
%        str2double(get(hObject,'String')) returns contents of edit4 as a double


% --- Executes during object creation, after setting all properties.
function edit4_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit5_Callback(hObject, eventdata, handles)
% hObject    handle to edit5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit5 as text
%        str2double(get(hObject,'String')) returns contents of edit5 as a double


% --- Executes during object creation, after setting all properties.
function edit5_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit6_Callback(hObject, eventdata, handles)
% hObject    handle to edit6 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit6 as text
%        str2double(get(hObject,'String')) returns contents of edit6 as a double


% --- Executes during object creation, after setting all properties.
function edit6_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit6 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit7_Callback(hObject, eventdata, handles)
% hObject    handle to edit7 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit7 as text
%        str2double(get(hObject,'String')) returns contents of edit7 as a double


% --- Executes during object creation, after setting all properties.
function edit7_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit7 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit8_Callback(hObject, eventdata, handles)
% hObject    handle to edit8 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit8 as text
%        str2double(get(hObject,'String')) returns contents of edit8 as a double


% --- Executes during object creation, after setting all properties.
function edit8_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit8 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit9_Callback(hObject, eventdata, handles)
% hObject    handle to edit9 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit9 as text
%        str2double(get(hObject,'String')) returns contents of edit9 as a double


% --- Executes during object creation, after setting all properties.
function edit9_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit9 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit10_Callback(hObject, eventdata, handles)
% hObject    handle to edit10 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit10 as text
%        str2double(get(hObject,'String')) returns contents of edit10 as a double


% --- Executes during object creation, after setting all properties.
function edit10_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit10 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in pushbutton13.
function pushbutton13_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton13 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% --- Executes on button press in pushbutton14.
function pushbutton14_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton14 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
gui_ocean_toolbox_handles = gcbf;%handles;
gui_searchtool([],gui_ocean_toolbox_handles)
%op_searchtool(request_tmp,h)
%==========================================================================
function varargout = uiopendap_toolboxpath(varargin)
%Add directories to the Matlab path necessary to make OPeNDAP GUIs work.
%
% THE PURPOSE OF THIS ROUTINE IS TO ADD THE FOLLOWING DIRECTORIES
% TO THE MATLAB PATH:
%
% (1) loaddap directory name
% (2) ml-opendap-toolbox directory name
%
% IF THE USER WOULD LIKE TO SKIP A STEP, ENTER "n" WHEN PROMPTED.
% THE "PATH" IS ONLY MODIFIED FOR THE CURRENT SESSION.
%
% EXAMPLE:
%
% >> uiopendap_toolboxpath
% Do you want to:
% (1) Add "loaddap" to your path?
% (2) Add mfiles to your path?
% Enter [1] or [2]: 2
%
% *******************************************************************
% * Adding mfiles to your Matlab path to use the OPeNDAP GUIs.
% * Adding 'C:\Documents and Settings\user1\My Documents\work\OPENDAP\SVN_GUIETTE\AIRS' to your Matlab path.
% * Adding 'C:\Documents and Settings\user1\My Documents\work\OPENDAP\SVN_GUIETTE\CommonFunctions' to your Matlab path.
% * Adding 'C:\Documents and Settings\user1\My Documents\work\OPENDAP\SVN_GUIETTE\GOES' to your Matlab path.
% * Adding 'C:\Documents and Settings\user1\My Documents\work\OPENDAP\SVN_GUIETTE\HYCOM' to your Matlab path.
% * Adding 'C:\Documents and Settings\user1\My Documents\work\OPENDAP\SVN_GUIETTE\MODIS' to your Matlab path.
% * Adding 'C:\Documents and Settings\user1\My Documents\work\OPENDAP\SVN_GUIETTE\OAFlux' to your Matlab path.
% * Adding 'C:\Documents and Settings\user1\My Documents\work\OPENDAP\SVN_GUIETTE\Pathfinder4km' to your Matlab path.
% * Adding 'C:\Documents and Settings\user1\My Documents\work\OPENDAP\SVN_GUIETTE\SeaWinds' to your Matlab path.
% *******************************************************************
%
% www.opendap.org
% MAY 2007

% MODIFICATION HISTORY:
%
% 2007/04/XX PCC Created
% 2007/05/07 CEB Edited

%   (OPTIONAL)
%   IF USED WITH INPUTS PROGRAM WILL
%   1 -- ADD "LOADDAP" TO PATH
%   2 -- ADD MFILES TO PATH
%

% Get the loaddap directory name

if (nargin==1)
    input1 = varargin{1};
    if (~ischar(input1))
        input1 = num2str(input1);
    end
    AddLoaddap = input1;
elseif (nargin>1)
    error('User must enter either "1" or "2".')
end

% PRELIMINARIES.
quot = sprintf('%s',''''); %SINGLE QUOTE MARK
tt = quot; %RENAME FOR CONCISENESS.
if (ispc), slash='\'; end
if (isunix), slash='/'; end
if (ismac), slash='/'; end

if (ispc)
    location = 'C:\opendap\ml-structs\'; % Default directory
elseif (ismac)
    location = '/usr/local/bin/'; % Default directory
elseif (isunix)
    location = '/usr/local/bin/'; % Default directory
end
AltLoaddapDirectory = strcat(slash,'aaa',slash,'bbb',slash,'...',slash);

if (~exist('input1','var'))
disp(['Do you want to:']);
disp(['(1) Add "loaddap" to your path?']);
disp(['(2) Add OPeNDAP Toolbox mfiles to your path?']);
AddLoaddap = input(['Enter [1] or [2] ([n] to cancel): '],'s');
end

if (strcmp(AddLoaddap,'n'))
    disp('Program cancelled.')
    if nargout
    status = 0;
    varargout{1} = status;
    end
    return
end
    
if (strcmp(AddLoaddap,'1'))
    
if exist('loaddap.m','file')
    %disp('"loaddap" is already in the Matlab path. add "loaddap" canceled.');
    if nargout
    status = 1;
    varargout{1} = status;
    end
    return
end

if exist(strcat(location,'loaddap.m'),'file')
    question_text = ['"loaddap" found in ',location,'. ',...
        'Would you like to add this to your path?'];
    ButtonName = questdlg(question_text,'Add "loaddap" ...','Yes','No','Yes');
    if strcmp(ButtonName,'Yes')
        tmp = 'y';
    else
        tmp = 'n';
    end
%     disp(['"loaddap" found in ',location,'.']);
%     tmp = input(['Would you like to add this to your path? ',...
%         '[y] or [n]: '],'s');
    if strcmpi(tmp,'y')
        eval(['addpath ' location ';'])
        %%%disp(['* Adding ' location ' to your Matlab path.'])
        disp(['The user might consider saving current path settings ',...
              'for future sessions.'])
        if nargout
        status = 1;
        varargout{1} = status;
        end
        return
    else %if strcmp(tmp,'n')
        %nothing
    end
end

% disp('*******************************************************************')
% disp('* loaddap must be in your Matlab path to use the OPeNDAP GUIs.')
% 
% QuestionString = ['* Provide a directory name for loaddap or n for none [/.../ or n]: '];
% AddLoaddap = input(['* Do you want to add ',LoaddapDirectory,' to your path? [y/n]: '],'s');
% if AddLoaddap == 'n'
%     LoaddapDirectory = input(QuestionString,'s');
%     if lower(LoaddapDirectory(1)) == 'n'
%         LoaddapDirectory = [];
%     end
% end

txt1 = '"loaddap" must be in your Matlab path to use the GUIs.';
txt2 = ' Please select the location of "loaddap":';
txt3 = '';
LoaddapDirectory = uigetdir(location,[txt1,txt2,txt3]);

%if ~isempty(LoaddapDirectory)
if LoaddapDirectory
    eval(['addpath ' LoaddapDirectory ';'])
    %%%disp(['* Adding ' LoaddapDirectory ' to your Matlab path.'])
else
    disp('add "loaddap" canceled.')
    if nargout
    status = 0;
    varargout{1} = status;
    end
    return
end

%%%disp('%==================================================================')
else %(strcmp(AddLoaddap,'2'))
%%%disp('%==================================================================')
%%%disp('* Adding OPeNDAP Toolbox mfiles to your Matlab path to use GUIs.')
% Now add all the subdirectories in the ml-opendap-toolbox directory to the 
% Matlab path. First get current directory.

CurrentDirectory = strrep(mfilename('fullpath'),mfilename,'');

DD = dir(CurrentDirectory);

for iNames=1:length(DD)
    if DD(iNames).isdir
    if DD(iNames).name(1) ~= '.' && isempty(findstr(DD(iNames).name,'OPeNDAP_ToolBoxPaths.m'))
        eval(['addpath(' tt CurrentDirectory DD(iNames).name tt ');'])
        %%%disp(['* Adding ' tt CurrentDirectory DD(iNames).name tt ' to your Matlab path.'])
    end
    end
end
addpath(CurrentDirectory); %ADD BASE DIRECTORY.
%%%disp(['* Adding ' tt CurrentDirectory tt ' to your Matlab path.'])

%%%disp('%==================================================================')
end

if nargout
    status = 0;
    varargout{1} = status;
end

return
%==========================================================================
function aa = ismac

dum = computer;
aa = strcmpi(dum,'mac') || strcmpi(dum,'maci');

%==========================================================================
function pushbutton15_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton15 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

op_version
%==========================================================================
function data = ReadMainCSV(filename,nvar) %,ncol)

% READ THE FILE.
%nvar = 7;
nrow = nvar+1;
ncol = 2;

if strcmpi(filename(end-2:end),'csv')
    
    fid = fopen(filename);
    data = textscan(fid,'%s','delimiter',',','treatAsEmpty','-');
    fclose(fid);
    
    data = data{1};
    hdg = data(1:ncol); %interesting -- one does not use hdg = data{1:ncol}
    data = data(ncol+1:ncol*nrow);
    data = reshape(data,ncol,nvar); data = data';
       
end%csv-file
%==========================================================================
function LogoSet(hObject, eventdata, handles)

% determine screen resolution and size of character in pixels
Units0=get(0,'Units'); % save initial settings
set(0,'Units','characters');
SSC=get(0,'ScreenSize'); % screen size in characters
set(0,'Units','pixels');
SSP=get(0,'ScreenSize'); % screen size in pixels
set(0,'Units',Units0); % restore to original units
ppcx=SSP(3)/SSC(3); % pixels per character along x
ppcy=SSP(4)/SSC(4); % pixels per character along y

[img,MAP]=imread('logo_opendap.jpg');
[NY,NX,N3]=size(img);
CX=(NX+8)/ppcx; % button size in characters including 4 pixel grace margin
CY=(NY+12)/ppcy;
set(handles.pushbutton24,'CData',img)
pos = get(handles.pushbutton24,'position'); %units will be in characters
set(handles.pushbutton24,'position',[pos(1),pos(2),CX,CY]);

% [img,MAP]=imread('logo_nasa.jpg');
% [NY,NX,N3]=size(img);
% CX=(NX+8)/ppcx; % button size in characters including 4 pixel grace margin
% CY=(NY+12)/ppcy;
% set(handles.pushbutton36,'CData',img)
% pos = get(handles.pushbutton36,'position'); %units will be in characters
% set(handles.pushbutton36,'position',[pos(1),pos(2),CX,CY]);

[img,MAP]=imread('logo_nasa1.jpg'); %('logo_nasamain.jpg');
[NY,NX,N3]=size(img);
CX=(NX+8)/ppcx; % button size in characters including 4 pixel grace margin
CY=(NY+12)/ppcy;
set(handles.pushbutton37,'CData',img)
pos = get(handles.pushbutton37,'position'); %units will be in characters
set(handles.pushbutton37,'position',[pos(1),pos(2),CX,CY]);

[img,MAP]=imread('logo_questionmark.jpg');
[N1,N2,N3]=size(img);
set(handles.pushbutton28,'string','')
set(handles.pushbutton29,'string','')
set(handles.pushbutton30,'string','')
set(handles.pushbutton31,'string','')
set(handles.pushbutton32,'string','')
set(handles.pushbutton33,'string','')
set(handles.pushbutton34,'string','')
set(handles.pushbutton35,'string','')
set(handles.pushbutton40,'string','')
set(handles.pushbutton45,'string','')
set(handles.pushbutton47,'string','')

set(handles.pushbutton28,'CData',img)
set(handles.pushbutton29,'CData',img)
set(handles.pushbutton30,'CData',img)
set(handles.pushbutton31,'CData',img)
set(handles.pushbutton32,'CData',img)
set(handles.pushbutton33,'CData',img)
set(handles.pushbutton34,'CData',img)
set(handles.pushbutton35,'CData',img)
set(handles.pushbutton40,'CData',img)
set(handles.pushbutton45,'CData',img)
set(handles.pushbutton47,'CData',img)

set(handles.pushbutton28,'Units','pixels')
set(handles.pushbutton29,'Units','pixels')
set(handles.pushbutton30,'Units','pixels')
set(handles.pushbutton31,'Units','pixels')
set(handles.pushbutton32,'Units','pixels')
set(handles.pushbutton33,'Units','pixels')
set(handles.pushbutton34,'Units','pixels')
set(handles.pushbutton35,'Units','pixels')
set(handles.pushbutton40,'Units','pixels')
set(handles.pushbutton45,'Units','pixels')
set(handles.pushbutton47,'Units','pixels')

pos = get(handles.pushbutton28,'position');
set(handles.pushbutton28,'position',[pos(1) pos(2) N1 N2])
pos = get(handles.pushbutton29,'position');
set(handles.pushbutton29,'position',[pos(1) pos(2) N1 N2])
pos = get(handles.pushbutton30,'position');
set(handles.pushbutton30,'position',[pos(1) pos(2) N1 N2])
pos = get(handles.pushbutton31,'position');
set(handles.pushbutton31,'position',[pos(1) pos(2) N1 N2])
pos = get(handles.pushbutton32,'position');
set(handles.pushbutton32,'position',[pos(1) pos(2) N1 N2])
pos = get(handles.pushbutton33,'position');
set(handles.pushbutton33,'position',[pos(1) pos(2) N1 N2])
pos = get(handles.pushbutton34,'position');
set(handles.pushbutton34,'position',[pos(1) pos(2) N1 N2])
pos = get(handles.pushbutton35,'position');
set(handles.pushbutton35,'position',[pos(1) pos(2) N1 N2])
pos = get(handles.pushbutton40,'position');
set(handles.pushbutton40,'position',[pos(1) pos(2) N1 N2])
pos = get(handles.pushbutton45,'position');
set(handles.pushbutton45,'position',[pos(1) pos(2) N1 N2])
pos = get(handles.pushbutton47,'position');
set(handles.pushbutton47,'position',[pos(1) pos(2) N1 N2])
%==========================================================================
function Help_Callback(hObject, eventdata, handles)
% hObject    handle to Help (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see
op_version


% --- Executes on button press in pushbutton16.
function pushbutton16_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton16 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

gui_softwaresettings


% --- Executes on button press in pushbutton17.
function pushbutton17_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton17 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

EnableDatasets(gcbf)
%figure(handles.main_handle)


% --- Executes on button press in pushbutton18.
function pushbutton18_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton18 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

EnableDatasets(gcbf)

% --- Executes on button press in pushbutton19.
function pushbutton19_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton19 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
url = 'http://www.opendap.org/support/index.html';
%url = 'http://www.oceanographicdata.org/Toolbox/support.html';
web(url,'-browser')

% --- Executes on button press in radiobutton1.
function radiobutton1_Callback(hObject, eventdata, handles)
% hObject    handle to radiobutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of radiobutton1

h = get_goes;
search = InputGet(hObject, eventdata, handles);
InputSetGUI(h,search)

% --- Executes on button press in radiobutton2.
function radiobutton2_Callback(hObject, eventdata, handles)
% hObject    handle to radiobutton2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of radiobutton2

h = get_hycom;
search = InputGet(hObject, eventdata, handles);
InputSetGUI(h,search)

% --- Executes on button press in radiobutton3.
function radiobutton3_Callback(hObject, eventdata, handles)
% hObject    handle to radiobutton3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of radiobutton3

h = get_oaflux;
search = InputGet(hObject, eventdata, handles);
InputSetGUI(h,search)

% --- Executes on button press in radiobutton4.
function radiobutton4_Callback(hObject, eventdata, handles)
% hObject    handle to radiobutton4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of radiobutton4

h = get_pathfinder1km;
if ~isempty(h)
search = InputGet(hObject, eventdata, handles);
InputSetGUI(h,search)
end

% --- Executes on button press in radiobutton5.
function radiobutton5_Callback(hObject, eventdata, handles)
% hObject    handle to radiobutton5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of radiobutton5

h = get_pathfinder4km;
search = InputGet(hObject, eventdata, handles);
InputSetGUI(h,search)

% --- Executes on button press in radiobutton6.
function radiobutton6_Callback(hObject, eventdata, handles)
% hObject    handle to radiobutton6 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of radiobutton6

h = get_seawinds;
search = InputGet(hObject, eventdata, handles);
InputSetGUI(h,search)

% --- Executes on button press in pushbutton44.
function pushbutton44_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton44 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
h = get_aviso_altimetry;
search = InputGet(hObject, eventdata, handles);
InputSetGUI(h,search)

% --- Executes on button press in pushbutton46.
function pushbutton46_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton46 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
h = get_ghrsst;
search = InputGet(hObject, eventdata, handles);
InputSetGUI(h,search)

% --- Executes on button press in radiobutton7.
function radiobutton7_Callback(hObject, eventdata, handles)
% hObject    handle to radiobutton7 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of radiobutton7

h = get_airs;
search = InputGet(hObject, eventdata, handles);
InputSetGUI(h,search)

% --- Executes on button press in radiobutton8.
function radiobutton8_Callback(hObject, eventdata, handles)
% hObject    handle to radiobutton8 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of radiobutton8

h = get_modis;

% --- Executes on button press in pushbutton39.
function pushbutton39_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton39 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

h = get_oceancolor;
search = InputGet(hObject, eventdata, handles);
InputSetGUI(h,search)

function InputSetGUI(varargin)
% Sets individual interfaces with lat/lon/dates.
%
% InputSetGUI(h,search)
% InputSetGUI(h,search,handle_names)
%
% INPUT(S):
%
% h -- handle to individual interface
% search -- structure obtained using "InputGet" from main interface;
%           must contain the following fields (content are strings)
%
%   .date1
%   .date2
%   .lon1
%   .lon2
%   .lat1
%   .lat2
%
% handle_names -- (optional) uicontrol object names;
% 
% explanation: handle_names are the fieldnames of the uicontrol objects
% obtained by typing ...
%
% handles = guidata(h)
%
% where "h" is the handle to the dataset interface.
% By default this program assumes that handle_names = {'edit1','edit2',...
% 'edit10'}. However, if the user inputs a different set of handle_names
% then he/she should be aware that they all must refer to "edit" uicontrol
% objects and that there must be at least 10 in the cell array.
%
% OUTPUT(S):
%
% [none]
%
% Christian Buckingham
% March 28, 2008

handle_names = {'edit1',...
                'edit2',...
                'edit3',...
                'edit4',...
                'edit5',...
                'edit6',...
                'edit7',...
                'edit8',...
                'edit9',...
                'edit10'};

if nargin == 2
    h = varargin{1};
    search = varargin{2};
elseif nargin == 3
    h = varargin{1};
    search = varargin{2};
    handle_names = varargin{3};
else
    error('incorrect number of inputs')
end

% climatology switch
climatology_switch = 0;
% if all(ismember(search.datatype,'climatology'))
%     climatology_switch = 1;
% end
    
date1 = search.date1;
date2 = search.date2;
lat1 = search.lat1;
lat2 = search.lat2;
lon1 = search.lon1;
lon2 = search.lon2;

latitude_switch = ~isempty(lat1) && ~isempty(lat2);
longitude_switch = ~isempty(lon1) && ~isempty(lon2);
date_switch = ~isempty(date1) && ~isempty(date2);

hh = guidata(h);

% Get handles to uicontrol objects.
handles = zeros(1,10);
for ii = 1:length(handle_names)
    handles(ii) = eval(['hh.',handle_names{ii}]);
end

% dates
if date_switch
set(handles(2),'string',date1(5:6))
set(handles(3),'string',date1(7:8))
set(handles(5),'string',date2(5:6))
set(handles(6),'string',date2(7:8))
if climatology_switch
    %do no set year
else
set(handles(1),'string',date1(1:4))
set(handles(4),'string',date2(1:4))
end
end

% lat
if latitude_switch
set(handles(7),'string',lat1)
set(handles(8),'string',lat2)
end

% lon
if longitude_switch
set(handles(9),'string',lon1)
set(handles(10),'string',lon2)
end

function edit11_Callback(hObject, eventdata, handles)
% hObject    handle to edit11 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit11 as text
%        str2double(get(hObject,'String')) returns contents of edit11 as a double

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes during object creation, after setting all properties.
function edit11_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit11 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit12_Callback(hObject, eventdata, handles)
% hObject    handle to edit12 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit12 as text
%        str2double(get(hObject,'String')) returns contents of edit12 as a double

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes during object creation, after setting all properties.
function edit12_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit12 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit13_Callback(hObject, eventdata, handles)
% hObject    handle to edit13 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit13 as text
%        str2double(get(hObject,'String')) returns contents of edit13 as a double

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes during object creation, after setting all properties.
function edit13_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit13 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit14_Callback(hObject, eventdata, handles)
% hObject    handle to edit14 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit14 as text
%        str2double(get(hObject,'String')) returns contents of edit14 as a double

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes during object creation, after setting all properties.
function edit14_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit14 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit15_Callback(hObject, eventdata, handles)
% hObject    handle to edit15 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit15 as text
%        str2double(get(hObject,'String')) returns contents of edit15 as a double

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes during object creation, after setting all properties.
function edit15_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit15 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit16_Callback(hObject, eventdata, handles)
% hObject    handle to edit16 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit16 as text
%        str2double(get(hObject,'String')) returns contents of edit16 as a double

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes during object creation, after setting all properties.
function edit16_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit16 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit17_Callback(hObject, eventdata, handles)
% hObject    handle to edit17 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit17 as text
%        str2double(get(hObject,'String')) returns contents of edit17 as a double

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes during object creation, after setting all properties.
function edit17_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit17 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit18_Callback(hObject, eventdata, handles)
% hObject    handle to edit18 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit18 as text
%        str2double(get(hObject,'String')) returns contents of edit18 as a double

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes during object creation, after setting all properties.
function edit18_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit18 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit19_Callback(hObject, eventdata, handles)
% hObject    handle to edit19 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit19 as text
%        str2double(get(hObject,'String')) returns contents of edit19 as a double

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes during object creation, after setting all properties.
function edit19_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit19 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function edit20_Callback(hObject, eventdata, handles)
% hObject    handle to edit20 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit20 as text
%        str2double(get(hObject,'String')) returns contents of edit20 as a double

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes during object creation, after setting all properties.
function edit20_CreateFcn(hObject, eventdata, handles)
% hObject    handle to edit20 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on selection change in popupmenu1.
function popupmenu1_Callback(hObject, eventdata, handles)
% hObject    handle to popupmenu1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns popupmenu1 contents as cell array
%        contents{get(hObject,'Value')} returns selected item from popupmenu1


% --- Executes during object creation, after setting all properties.
function popupmenu1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to popupmenu1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on selection change in popupmenu2.
function popupmenu2_Callback(hObject, eventdata, handles)
% hObject    handle to popupmenu2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns popupmenu2 contents as cell array
%        contents{get(hObject,'Value')} returns selected item from popupmenu2


% --- Executes during object creation, after setting all properties.
function popupmenu2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to popupmenu2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in checkbox1.
function checkbox1_Callback(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in checkbox2.
function checkbox2_Callback(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in checkbox3.
function checkbox3_Callback(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in checkbox4.
function checkbox4_Callback(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in checkbox5.
function checkbox5_Callback(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in checkbox6.
function checkbox6_Callback(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in checkbox7.
function checkbox7_Callback(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in checkbox8.
function checkbox8_Callback(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in checkbox9.
function checkbox9_Callback(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in checkbox10.
function checkbox10_Callback(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in checkbox11.
function checkbox11_Callback(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in checkbox12.
function checkbox12_Callback(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in checkbox13.
function checkbox13_Callback(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in checkbox14.
function checkbox14_Callback(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in checkbox15.
function checkbox15_Callback(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in checkbox16.
function checkbox16_Callback(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in checkbox17.
function checkbox17_Callback(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in pushbutton20.
function pushbutton20_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton20 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

set(handles.checkbox1,'value',0);
set(handles.checkbox2,'value',0);
set(handles.checkbox3,'value',0);
set(handles.checkbox4,'value',0);
set(handles.checkbox5,'value',0);
set(handles.checkbox6,'value',0);
set(handles.checkbox7,'value',0);
set(handles.checkbox8,'value',0);
set(handles.checkbox9,'value',0);
set(handles.checkbox10,'value',0);
set(handles.checkbox11,'value',0);
set(handles.checkbox12,'value',0);
set(handles.checkbox13,'value',0);
set(handles.checkbox14,'value',0);
set(handles.checkbox15,'value',0);
set(handles.checkbox16,'value',0);
set(handles.checkbox17,'value',0);
set(handles.checkbox23,'value',0);

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in pushbutton21.
function pushbutton21_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton21 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

set(handles.checkbox1,'value',1);
set(handles.checkbox2,'value',1);
set(handles.checkbox3,'value',1);
set(handles.checkbox4,'value',1);
set(handles.checkbox5,'value',1);
set(handles.checkbox6,'value',1);
set(handles.checkbox7,'value',1);
set(handles.checkbox8,'value',1);
set(handles.checkbox9,'value',1);
set(handles.checkbox10,'value',1);
set(handles.checkbox11,'value',1);
set(handles.checkbox12,'value',1);
set(handles.checkbox13,'value',1);
set(handles.checkbox14,'value',1);
set(handles.checkbox15,'value',1);
set(handles.checkbox16,'value',1);
set(handles.checkbox17,'value',1);
set(handles.checkbox23,'value',1);

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in checkbox18.
function checkbox18_Callback(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in checkbox19.
function checkbox19_Callback(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in checkbox20.
function checkbox20_Callback(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in checkbox21.
function checkbox21_Callback(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in checkbox22.
function checkbox22_Callback(hObject, eventdata, handles)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

%==========================================================================
function search = InputGet(hObject, eventdata, handles, switch_filter)

% switch_filter -- switch that tells us whether called by "Filter Datasets"
%   section of the GUI or not. 0 if no, 1 if yes.

% PRELIMINARIES.
variable = {};
topic = {};
datatype = {}; %time_series,climatology
datasource = {}; %satellite,model
date1 = '';
date2 = '';
lat1 = '';
lat2 = '';
lon1 = '';
lon2 = '';
res_time = '';
res_latlon = '';
keyword = '';

% VARIABLE.

% variable = {'wind',...
%     'wind stress',...
%     'air temperature',...
%     'air pressure',...
%     'cloud cover',...
%     'water vapor',...
%     'heat flux',...
%     'temperature',...
%     'salinity',...
%     'density',...
%     'currents',...
%     'mixed layer depth',...
%     'sea surface temperature',...
%     'sea surface salinity',...
%     'sea surface height',...
%     'ice',...
%     };

variable = ...
    {get(handles.checkbox1,'string'),...
    get(handles.checkbox2,'string'),...
    get(handles.checkbox3,'string'),...
    get(handles.checkbox4,'string'),...
    get(handles.checkbox5,'string'),...
    get(handles.checkbox6,'string'),...
    get(handles.checkbox7,'string'),...
    get(handles.checkbox8,'string'),...
    get(handles.checkbox9,'string'),...
    get(handles.checkbox10,'string'),...
    get(handles.checkbox11,'string'),...
    get(handles.checkbox12,'string'),...
    get(handles.checkbox13,'string'),...
    get(handles.checkbox14,'string'),...
    get(handles.checkbox15,'string'),...
    get(handles.checkbox16,'string'),...
    get(handles.checkbox17,'string'),...
    get(handles.checkbox23,'string')};

variable_switch = ...
    [get(handles.checkbox1,'value'),...
    get(handles.checkbox2,'value'),...
    get(handles.checkbox3,'value'),...
    get(handles.checkbox4,'value'),...
    get(handles.checkbox5,'value'),...
    get(handles.checkbox6,'value'),...
    get(handles.checkbox7,'value'),...
    get(handles.checkbox8,'value'),...
    get(handles.checkbox9,'value'),...
    get(handles.checkbox10,'value'),...
    get(handles.checkbox11,'value'),...
    get(handles.checkbox12,'value'),...
    get(handles.checkbox13,'value'),...
    get(handles.checkbox14,'value'),...
    get(handles.checkbox15,'value'),...
    get(handles.checkbox16,'value'),...
    get(handles.checkbox17,'value'),...
    get(handles.checkbox23,'value')];

iswitch = find(variable_switch);
variable = variable(iswitch);

% TOPIC.
% this variable was eliminated as of 2008/01/22

% DATATYPE.
ii = 1;
tmp = get(handles.checkbox18,'value');
tmp_str = get(handles.checkbox18,'string');
if tmp, datatype{ii} = tmp_str; ii=ii+1;end
tmp = get(handles.checkbox19,'value');
tmp_str = get(handles.checkbox19,'string');
if tmp, datatype{ii} = tmp_str; ii=ii+1;end
% tmp = get(handles.checkbox19,'value'); %add for near-real-time
% tmp_str = get(handles.checkbox19,'string');
% if tmp, datatype{ii} = tmp_str; ii=ii+1;end

% DATASOURCE.
ii = 1;
tmp = get(handles.checkbox21,'value');
tmp_str = get(handles.checkbox21,'string');
if tmp, datasource{ii} = tmp_str; ii=ii+1;end
tmp = get(handles.checkbox22,'value');
tmp_str = get(handles.checkbox22,'string');
if tmp, datasource{ii} = tmp_str; ii=ii+1;end

%==========================================================================
% DATE.
yyyy = get(handles.edit11,'String');
mm = get(handles.edit12,'String');
dd = get(handles.edit13,'String');
if (length(mm)==1); mm=['0',mm]; end
if (length(dd)==1); dd=['0',dd]; end
% if (~isempty(yyyy))
%     if (isempty(mm)); mm=['01']; end %set(handles.edit12,'String',mm); end
%     if (isempty(dd)); dd=['01']; end %set(handles.edit13,'String',mm); end
% end
date1=[yyyy,mm,dd];
yyyy1 = yyyy;
mm1 = mm;
dd1 = dd;

yyyy = get(handles.edit14,'String');
mm = get(handles.edit15,'String');
dd = get(handles.edit16,'String');
if (length(mm)==1); mm=['0',mm]; end
if (length(dd)==1); dd=['0',dd]; end
% if (~isempty(yyyy))
%     if (isempty(mm)); mm=['01']; end %set(handles.edit15,'String',mm); end
%     if (isempty(dd)); dd=['01']; end %set(handles.edit16,'String',mm); end
% end
yyyy2 = yyyy;
mm2 = mm;
dd2 = dd;
%==========================================================================
% Set the date for given situations.
% This is pretty complicated because we want it to respond to the user
% immediately.
switch_noprocess = 0;

if ~isempty(yyyy1) && isempty(yyyy2) ...
    && isempty(mm1) && isempty(dd1) && isempty(mm2) && isempty(dd2)
%         mm1 = '01';
%         dd1 = '01';
%         yyyy2 = yyyy1; %set(handles.edit14,'String',yyyy2);
%         mm2 = '12';
%         dd2 = '31';
        switch_noprocess = 1;
elseif ~isempty(yyyy1) && isempty(yyyy2) ...
    && ~isempty(mm1) && isempty(dd1) && isempty(mm2) && isempty(dd2)
%         dd1 = '01';
%         yyyy2 = yyyy1;
%         mm2 = mm1;
%         dd2 = '31';
        switch_noprocess = 1;
elseif ~isempty(yyyy1) && isempty(yyyy2) ...
    && ~isempty(mm1) && ~isempty(dd1) && isempty(mm2) && isempty(dd2)
%         yyyy2 = yyyy1;
%         mm2 = mm1;
%         dd2 = dd1;
        switch_noprocess = 1;
elseif  ~isempty(yyyy1) && ~isempty(yyyy2) ...
    && isempty(mm1) && isempty(dd1) && isempty(mm2) && isempty(dd2)
        mm1 = '01';
        dd1 = '01';
        mm2 = '12';
        dd2 = '31';
elseif  ~isempty(yyyy1) && ~isempty(yyyy2) ...
    && ~isempty(mm1) && isempty(dd1) && isempty(mm2) && isempty(dd2)
%         dd1 = '01';
%         mm2 = '12';
%         dd2 = '31';
        switch_noprocess = 1;
elseif  ~isempty(yyyy1) && ~isempty(yyyy2) ...
    && ~isempty(mm1) && ~isempty(dd1) && isempty(mm2) && isempty(dd2)
%         mm2 = '12';
%         dd2 = '31';
        switch_noprocess = 1;
elseif  ~isempty(yyyy1) && ~isempty(yyyy2) ...
    && ~isempty(mm1) && ~isempty(dd1) && ~isempty(mm2) && isempty(dd2)
%         dd2 = '31';
        switch_noprocess = 1;
elseif ~isempty(yyyy1) && ~isempty(yyyy2) ...
    && ~isempty(mm1) && isempty(dd1) && ~isempty(mm2) && isempty(dd2)
    %do nothing
        %mm1 = '01';
        %mm2 = '12';
        dd1 = '01';
        dd2 = '31';
elseif ~isempty(yyyy1) && ~isempty(yyyy2) ...
    && ~isempty(mm1) && ~isempty(dd1) && ~isempty(mm2) && ~isempty(dd2)
    %do nothing
else
    switch_noprocess = 1;
end

if switch_noprocess
    date1 = '';
    date2 = '';
else
    date1=[yyyy1,mm1,dd1];
    date2=[yyyy2,mm2,dd2];
end

% if ~isempty(yyyy1) && isempty(yyyy2)
%     if isempty(mm1)
%         mm1 = '01';
%         dd1 = '01';
%         yyyy2 = yyyy1; %set(handles.edit14,'String',yyyy2);
%         mm2 = '12';
%         dd2 = '31';
%     else %mm1 not empty
%         if isempty(dd1)
%             dd1 = '01';
%             yyyy2 = yyyy1;
%             mm2 = mm1;
%             dd2 = '31';
%         else %dd1 not empty
%             if isempty(mm2) && isempty(dd2)
%                 yyyy2 = yyyy1;
%                 mm2 = mm1;
%                 dd2 = dd1;
%             else
%             switch_noprocess = 1; %do not do anything
%             end
%         end
%     end
% elseif ~isempty(yyyy1) && ~isempty(yyyy2)
%     if isempty(mm1) && isempty(mm2)
%         mm1 = '01';
%         dd1 = '01';
%         mm2 = '12';
%         dd2 = '31';
%     elseif isempty(mm1) && ~isempty(mm2)
%         switch_noprocess = 1; %do not do anything
%     elseif ~isempty(mm2) && isempty(mm2) %mm1 not empty && mm2 is empty
%         if isempty(dd1)
%             dd1 = '01';
%             if isempty(dd2)
%                 dd2 = '31';
%             else
%                 switch_noprocess = 1; %do not do anything
%             end
%         else %dd1 not empty
%             switch_noprocess = 1; %do not do anything
%         end
%     elseif ~isempty(mm2) && ~isempty(mm2) && ~isempty(dd1)
%         dd2 = '31';
%     end
% else
%     switch_noprocess = 1; %do not do anything
% end
%==========================================================================
% % Set fields.
% set(handles.edit11,'String',date1(1:4))
% set(handles.edit12,'String',date1(5:6))
% set(handles.edit13,'String',date1(7:8))
% set(handles.edit14,'String',date2(1:4))
% set(handles.edit15,'String',date2(5:6))
% set(handles.edit16,'String',date2(7:8))
%==========================================================================
% LAT/LON.
lat1 = get(handles.edit17,'String');
lat2 = get(handles.edit18,'String');
lon1 = get(handles.edit19,'String');
lon2 = get(handles.edit20,'String');

switch_noprocess_lat = 0;

if ~isempty(lat1) && isempty(lat2)
    %lat2 = '90';
    switch_noprocess_lat = 1;
end
if ~isempty(lat2) && isempty(lat1)
    %lat1 = '-90';
    switch_noprocess_lat = 1;
end

if switch_noprocess_lat
    lat1 = '';
    lat2 = '';
end

switch_noprocess_lon = 0;

if ~isempty(lon1) && isempty(lon2)
    %lon2 = '180';
    switch_noprocess_lon = 1;
end
if ~isempty(lon2) && isempty(lon1)
    %lon1 = '-180';
    switch_noprocess_lon = 1;
end

if switch_noprocess_lon
    lon1 = '';
    lon2 = '';
end

% % IF PROCESS LATITUDE SEARCH BUT NOT LONGITUDE SEARCH.
% if ~switch_noprocess_lat && switch_noprocess_lon
%     lon1 = '-180'; %default set of values
%     lon2 = '180'; %default set of values
%     %leave latitude values as is
% end
% 
% % IF PROCESS LONGITUDE SEARCH BUT NOT LATITUDE SEARCH.
% if switch_noprocess_lat && ~switch_noprocess_lon
%     lat1 = '-90'; %default set of values
%     lat2 = '90'; %default set of values
%     %leave longitude values as is
% end
% 
% % IF PROCESS NEITHER ...
% if switch_noprocess_lat && switch_noprocess_lon
%     lat1 = '-90';
%     lat2 = '90';
%     lon1 = '-180';
%     lon2 = '180';
% end
%==========================================================================
% RESOLUTION.
res_time = '';%get(handles.popupmenu1,'');
res_latlon = '';%get(handles.popupmenu2,'');

% KEYWORD.
% this variable was eliminated as of 2008/01/22

% ANY,ALL.
% txt = get(handles.popupmenu3,'string'); %for both date and lat/lon.
% val = get(handles.popupmenu4,'value');
% str = txt{val};
date_all_switch = 0; %strcmpi(str,'all');
latlon_all_switch = 0; %strcmpi(str,'all');

search.variable = variable;
search.topic = topic;
search.datatype = datatype;
search.datasource = datasource;
search.date1 = date1;
search.date2 = date2;
search.lat1 = lat1;
search.lat2 = lat2;
search.lon1 = lon1;
search.lon2 = lon2;
search.res_time = res_time;
search.res_latlon = res_latlon;
search.keyword = keyword;
search.date_all_switch = date_all_switch;
search.latlon_all_switch = latlon_all_switch;

%==========================================================================

% --- Creates the "masterdatabase.mat" file for the front-end search tool.
function pushbutton22_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton22 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Create master database from individual databases.
filename = 'masterdatabase.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname)-length(mfilename));
    filename = [pname,filename];
end
MakeDatabase(filename)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = hObject;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in pushbutton23.
function pushbutton23_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton23 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);

% --- Executes on button press in pushbutton24.
function pushbutton24_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton24 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
url = 'http://www.opendap.org/';
web(url,'-browser')

% --- Executes on button press in pushbutton26.
function pushbutton26_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton26 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
EnableDatasets(gcbf)

%==========================================================================
function EnableDatasets(varargin)
% Enable/Disable Graphical User Interface Objects on Main GUI.
%
% EnableDatasets(main_handle)
% EnableDatasets(function_name,main_handle)
%
% INPUT(S):
%
%   function_name -- string or cell array of strings of valid
%                    databases.
%                    If not specified, function_name defaults to a
%                    pre-defined set of guinames.
%
%   main_handle -- handle to main gui.
%
% OUTPUT(S):
%
%   [none] --
%
% EXAMPLE:
%
% working_datasets ={'get_airs','get_goes','get_hycom','get_modis','get_oaflux',...
%                    'get_pathfinder4km','get_seawinds'};
% EnableDatasets(working_datasets) --> enables all the databases listed
%                                         above, while it disables those
%                                         not listed.
%
% OPeNDAP Science Team
% Copyright 2007
% $Version 1.01$

%==========================================================================
% Christian Buckingham
% July 2007
%
% REVISION HISTORY:
% 2007/07/01 created, ceb
% 2008/01/08 renamed mfile, removed pushbuttons, ceb
%==========================================================================

if nargin == 1 %this is another way of saying 'EnableAll'
    
    main_handle = varargin{1};
    
elseif nargin == 2
    
    function_name = varargin{1};    
    main_handle = varargin{2};
 
else
    error('number of input arguments must be 1 or 2.')
end
if ~isnumeric(main_handle)
    error('input "main_handle" must be numeric.')
end

load NetworkVerification.mat
if nargin == 1
    function_name = working_database;
end
%==========================================================================
tmp = guihandles(main_handle);
ndatasets = length(guihandlenames);
gui_handles = zeros(1,ndatasets);
for ii = 1:ndatasets
    gui_handles(ii) = eval(strcat('tmp.',guihandlenames{ii}));
end

turnon = zeros(1,length(gui_handles));
[dummy,ia,ib] = intersect(working_database,function_name);
turnon(ia) = 1;

txt = {'off','on'};
for ii = 1:length(gui_handles)
    
    turnon_flag = turnon(ii);
    tmp = txt{turnon_flag + 1};
    set(gui_handles(ii),'Enable',tmp);
    set(gui_handles(ii),'Visible','On');
    
end

return %ENDOFFUNCTION
%==========================================================================
% --- Executes on button press in pushbutton27.
function pushbutton27_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton27 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

set(handles.edit11,'string','');
set(handles.edit12,'string','');
set(handles.edit13,'string','');
tmp = datestr(now,26); tmp = strrep(tmp,'/','');
yyyy = tmp(1:4);
mm = tmp(5:6);
dd = tmp(7:8);
set(handles.edit14,'string','');
set(handles.edit15,'string','');
set(handles.edit16,'string','');
set(handles.edit17,'string','');
set(handles.edit18,'string','');
set(handles.edit19,'string','');
set(handles.edit20,'string','');

% --- Executes on button press in pushbutton28.
function pushbutton28_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton28 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
url = 'http://coastwatch.pfeg.noaa.gov/infog/GA_ssta_las.html';
web(url,'-browser')

% --- Executes on button press in pushbutton29.
function pushbutton29_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton29 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
url = 'http://hycom.coaps.fsu.edu/data/atlantic_info.html';
web(url,'-browser')

% --- Executes on button press in pushbutton30.
function pushbutton30_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton30 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
url = 'http://oaflux.whoi.edu';
web(url,'-browser')

% --- Executes on button press in pushbutton31.
function pushbutton31_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton31 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
url = 'http://disc.gsfc.nasa.gov/AIRS/airsL3_STD.shtml';
web(url,'-browser')

% --- Executes on button press in pushbutton32.
function pushbutton32_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton32 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% --- Executes on button press in pushbutton33.
function pushbutton33_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton33 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
url = 'http://satdat1.gso.uri.edu/opendap/Pathfinder/Pathfinder1km/pathfinder_1km.html';
web(url,'-browser')

% --- Executes on button press in pushbutton34.
function pushbutton34_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton34 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
url = 'http://www.nodc.noaa.gov/sog/pathfinder4km/userguide.html';
web(url,'-browser')

% --- Executes on button press in pushbutton35.
function pushbutton35_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton35 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
url = 'http://podaac-www.jpl.nasa.gov/quikscat/qscat_doc.html';
web(url,'-browser')
pause(1)
url = 'http://podaac-www.jpl.nasa.gov/PRODUCTS/p109.html';
web(url,'-browser')

% --- Executes during object creation, after setting all properties.
function pushbutton35_CreateFcn(hObject, eventdata, handles)
% hObject    handle to pushbutton35 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

function InputSet(hObject, eventdata, handles, search)
% This function sets the gui.
quot = sprintf('%s',''''); %SINGLE QUOTE MARK

% PRELIMINATRIES.
variable = search.variable;
topic = search.topic;
datatype = search.datatype;
datasource = search.datasource;
date1 = search.date1;
date2 = search.date2;
lat1 = search.lat1;
lat2 = search.lat2;
lon1 = search.lon1;
lon2 = search.lon2;
res_time = search.res_time;
res_latlon = search.res_latlon;
keyword = search.keyword;

% VARIABLE.
nvar = length(variable);

% Get all checkbox 'string'.
variable_possible = ...
    {get(handles.checkbox1,'string'),...
    get(handles.checkbox2,'string'),...
    get(handles.checkbox3,'string'),...
    get(handles.checkbox4,'string'),...
    get(handles.checkbox5,'string'),...
    get(handles.checkbox6,'string'),...
    get(handles.checkbox7,'string'),...
    get(handles.checkbox8,'string'),...
    get(handles.checkbox9,'string'),...
    get(handles.checkbox10,'string'),...
    get(handles.checkbox11,'string'),...
    get(handles.checkbox12,'string'),...
    get(handles.checkbox13,'string'),...
    get(handles.checkbox14,'string'),...
    get(handles.checkbox15,'string'),...
    get(handles.checkbox16,'string'),...
    get(handles.checkbox17,'string'),...
    get(handles.checkbox23,'string')};

nvar_possible = length(variable_possible);
for ivar = 1:nvar_possible
    statement = ['set(handles.checkbox',...
            num2str(ivar),',',quot,'value',quot,','];
    if ismember(variable_possible{ivar},variable)
        eval(strcat(statement,'1)'))
    else
        eval(strcat(statement,'0)'))
    end
end

% TOPIC.
% eliminated

set(handles.checkbox18,'value',0);
set(handles.checkbox19,'value',0);
set(handles.checkbox20,'value',0);
set(handles.checkbox21,'value',0);
set(handles.checkbox22,'value',0);

% DATATYPE.
if any(ismember(datatype,'time series')), set(handles.checkbox18,'value',1); end
if any(ismember(datatype,'climatology')), set(handles.checkbox19,'value',1); end

% DATASOURCE.
if any(ismember(datasource,'in-situ')), set(handles.checkbox20,'value',1); end
if any(ismember(datasource,'satellite')), set(handles.checkbox21,'value',1); end
if any(ismember(datasource,'model')), set(handles.checkbox22,'value',1); end

% DATE.
if ~isempty(date1)
yyyy = date1(1:4);
mm = date1(5:6);
dd = date1(7:8);
set(handles.edit11,'String',yyyy); %set(main_handle.edit1,'String'));
set(handles.edit12,'String',mm); %set(main_handle.edit2,'String'));
set(handles.edit13,'String',dd); %set(main_handle.edit3,'String'));
end

if ~isempty(date2)
yyyy = date2(1:4);
mm = date2(5:6);
dd = date2(7:8);
set(handles.edit14,'String',yyyy); %set(main_handle.edit1,'String'));
set(handles.edit15,'String',mm); %set(main_handle.edit2,'String'));
set(handles.edit16,'String',dd); %set(main_handle.edit3,'String'));
end

% LAT/LON.
if ~isempty(lat1) && ~isempty(lon1)
if isnumeric(lat1), lat1 = str2num(lat1); end
if isnumeric(lat2), lat2 = str2num(lat2); end
if isnumeric(lon1), lon1 = str2num(lon1); end
if isnumeric(lon2), lon2 = str2num(lon2); end

set(handles.edit17,'String',lat1); %set(main_handle.edit7,'String'));
set(handles.edit18,'String',lat2); %set(main_handle.edit8,'String'));
set(handles.edit19,'String',lon1); %set(main_handle.edit9,'String'));
set(handles.edit20,'String',lon2); %set(main_handle.edit10,'String'));
end

% RESOLUTION.
%set(handles.popupmenu1,'string',res_time);
%set(handles.popupmenu2,'string',res_latlon);

% KEYWORD.
% eliminated
%==========================================================================
function MakeDatabase(filename_input)
% Creates large .mat file from individual .csv files.
%
% Christian Buckingham
% January 2008

load NetworkVerification.mat
%interface_directories tells the user which graphical user interfaces are
%included with the Toolbox. Use this to determine which .csv files
%are there.
len = length(interface_directories);
    ii = 1;
    directory = interface_directories{ii};
    filename = strcat('database_',lower(directory),'.csv');
    switch_csv = exist(filename,'file');
    %is .csv file present? 1 = yes 0 = no
    if switch_csv
        [hdr,tmp] = op_csvread(filename);
    end
    data = tmp;
for ii = 2:len
    directory = interface_directories{ii};
    filename = strcat('database_',lower(directory),'.csv');
    switch_csv = exist(filename,'file');
    %is .csv file present? 1 = yes 0 = no
    if switch_csv
        [hdr,tmp] = op_csvread(filename);
    end
    [m,n] = size(data);
    [mm,nn] = size(tmp);
    data(m+1:m+mm,:) = tmp;
end%ii

% Create master database from individual databases.
% save(strcat(pname,fname),'hdr','data');
save(filename_input,'hdr','data');


% --- Executes on button press in pushbutton37.
function pushbutton37_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton37 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

url = 'http://www.nasa.gov';
web(url,'-browser')


% --- Executes on button press in pushbutton38.
function pushbutton38_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton38 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

file1 = 'ocean_toolbox.m';
file2 = 'readme';
if (~isdeployed)
    pname = which(fname);
    pname = pname(1:length(pname)-length(file1));
    file2 = [pname,'readme'];
end
open(file2)

function DateSet(hObject, eventdata, handles)

filename = 'masterdatabase.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname)-length(mfilename));
    filename = [pname,filename];
end
load('-mat',filename,'data','hdr')

iloc = strcmpi(hdr,'start_time');
iloc = find(iloc == 1);
% A = data(:,iloc); %mlint shows an error here wrt ":" but no error.
% B = data(:,iloc+1); %mlint shows an error here wrt ":" but no error.
% B = strrep(B,'present',num2str(round(op_greg2epoch(datevec(now)))));
% A = str2double(A);
% B = str2double(B);
A = data(:,iloc); %mlint shows an error here wrt ":" but no error.
B = data(:,iloc+1); %mlint shows an error here wrt ":" but no error.
A = strrep(A,'present',num2str(round(op_greg2epoch(datevec(now)))));
B = strrep(B,'present',num2str(round(op_greg2epoch(datevec(now)))));
A = str2num(char(A));
B = str2num(char(B));
minA = min(A);
maxB = max(B);
buffer = 0*3600*24;%buffer to ensure available date range is not-so-recent
gtimeA = op_epoch2greg(minA);
gtimeB = op_epoch2greg(maxB - buffer);
date1 = datestr(gtimeA,29);
date2 = datestr(gtimeB,29);
%txt = ['Available time range: [',date1,' to ',date2,']'];
txt = ['Available time range: [',date1,' to ',date2,']*'];
set(handles.text66,'string',txt);

% Not sure about the above code; ending date may be wrong since it does not
% connect to any databases to determine the stop date.

return

% --- Executes on button press in pushbutton40.
function pushbutton40_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton40 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

url = 'http://oceancolor.gsfc.nasa.gov/';
web(url,'-browser')

% --- Executes on button press in checkbox23.
function checkbox23_Callback(hObject, eventdata, handles)
% hObject    handle to checkbox23 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of checkbox23

% Get input from user.
switch_filter = 0;
search = InputGet(hObject, eventdata, handles, switch_filter);

% Search.
hfig = gcbf;
function_name = op_searchtool(search);
EnableDatasets(function_name,hfig);


% --- Executes on button press in pushbutton41.
function pushbutton41_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton41 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
url = 'http://www.oceanographicdata.org/Toolbox/documentation.html';
web(url,'-browser')

% --- Executes on button press in pushbutton42.
function pushbutton42_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton42 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% This button loads the last time and lat/lon fields.
function pushbutton43_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton43 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

tmp_filename = 'gui_ocean_toolbox.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname) - length(mfilename));
    tmp_filename = [pname,tmp_filename];
end

if exist(tmp_filname,'file')
    load(tmp_filename)
end

% --- Executes on button press in pushbutton45.
function pushbutton45_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton45 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
url = 'http://www.aviso.oceanobs.com/';
web(url,'-browser')

% --- Executes on button press in pushbutton47.
function pushbutton47_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton47 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
url = 'http://www.ghrsst-pp.org/';
web(url,'-browser')

% --- Executes on button press in pushbutton48.
function pushbutton48_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton48 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% disp(['Testing the matlab client "loaddap" ...'])
% pause(.1)
% url = 'http://test.opendap.org/opendap/nph-dods/data/nc/fnoc1.nc';
% loaddap('-e',url)
% if exist('dods_err_msg','var')
%     if dods_err
%         disp(dods_err_msg)
%     end
% end
% if dods_err
%     disp(dods_err_msg)
%     disp(['loaddap(',url,')'])
%     disp(['has failed to acquire data. Please try another URL address.'])
% elseif ~exist('u','var')
%     disp(['loaddap(',url,')'])
%     disp(['does not appear to be working. Please check the URL or ensure '])
%     disp(['you have a working copy of the matlab client. For more information '])
%     disp(['see www.opendap.org.'])
% else
%     disp(['loaddap(',url,')'])
%     disp(['has successfully acquired data. The matlab client is working properly.'])
% end

return %endoffunction


% --- Executes on button press in pushbutton49.
function pushbutton49_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton49 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


