function varargout = gui_goes(varargin)
% Boots-up GOES GUI, interacts with user via interface.
% gui_goes M-file for gui_goes.fig
%
% INPUT(S):
%
%   [none]
%
% OUTPUT(S):
%
%   h -- (optional) GUI handle
%
% OPeNDAP Science Team
% Copyright 2007, 2008
% $Version 2.0.0$

%==========================================================================
% Meri Sheremet
% June 2007
%
% REVISION HISTORY:
% 2007/01/01 created, ms
% 2008/06/15 modified for compiled version, ceb
%==========================================================================

warning('off','MATLAB:dispatcher:InexactMatch');
% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @gui_goes_OpeningFcn, ...
                   'gui_OutputFcn',  @gui_goes_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT
warning('on','MATLAB:dispatcher:InexactMatch');

% --- Executes just before gui_goes is made visible.
function gui_goes_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to gui_goes (see VARARGIN)

% Define handles "openfigure" field.
if ~isfield(handles,'openfigure')
    GetDataSetRanges(handles)
    handles.openfigure = 0; %set equal to zero on the first time.
end

% Set interface name.
filename = 'get_goes';
txt = ['NASA/REASoN Ocean Data Portal - '];
tmp1 = ['GOES GUI'];
tmp2 = '';
txt = [txt,tmp1];
if (~isdeployed)
    tmp2 = strrep(op_version('mfile',filename),'Version ','');
    txt = [txt,' (Ver ',tmp2,')'];
end
set(hObject,'Name',txt);
set(handles.radiobutton2,'Enable','On');

%Place logos on the GUI    
% determine screen resolution and size of character in pixels
Units0=get(0,'Units'); % save initial settings
set(0,'Units','characters');
SSC=get(0,'ScreenSize'); % screen size in characters
set(0,'Units','pixels');
SSP=get(0,'ScreenSize'); % screen size in pixels
set(0,'Units',Units0); % restore to original units
ppcx=SSP(3)/SSC(3); % pixels per character along x
ppcy=SSP(4)/SSC(4); % pixels per character along y

[img,MAP]=imread('logo_opendap.jpg');
[NY,NX,N3]=size(img);
CX=(NX+8)/ppcx;         % button size in characters including 4 pixel grace margin
CY=(NY+12)/ppcy;
set(handles.pushbutton4,'CData',img)
pos = get(handles.pushbutton4,'position'); %units will be in characters
set(handles.pushbutton4,'position',[pos(1),pos(2),CX,CY]);

[img,MAP]=imread('logo_nasa1.jpg');
[NY,NX,N3]=size(img);
CX=(NX+8)/ppcx;         % button size in characters including 4 pixel grace margin
CY=(NY+12)/ppcy;
set(handles.pushbutton6,'CData',img)
pos = get(handles.pushbutton6,'position'); %units will be in characters
set(handles.pushbutton6,'position',[pos(1),pos(2),CX,CY]);  

[img,MAP]=imread('logo_noaa_coastwatch.jpg');
[NY,NX,N3]=size(img);
CX=(NX+8)/ppcx;
CY=(NY+12)/ppcy;
set(handles.pushbutton3,'CData',img)
pos = get(handles.pushbutton3,'position'); %units will be in characters
set(handles.pushbutton3,'position',[pos(1),pos(2),CX,CY]);

set(handles.edit11,'String',num2str(1));
set(handles.edit12,'String',num2str(1));
set(handles.edit13,'String',num2str(1));

txt=['Help'];
op_tooltipwrap(handles.pushbutton7,txt,50);

[img,MAP]=imread('logo_questionmark.jpg');
% [NY,NX,N3]=size(img);
% CX=(NX+8)/ppcx;
% CY=(NY+12)/ppcy;
% set(handles.pushbutton10,'CData',img)
% pos = get(handles.pushbutton10,'position'); %units will be in characters
% set(handles.pushbutton10,'position',[pos(1),pos(2),CX,CY]);
[N1,N2,N3]=size(img);
set(handles.pushbutton7,'string','')
set(handles.pushbutton7,'CData',img)
set(handles.pushbutton7,'Units','pixels')
pos = get(handles.pushbutton7,'position');
set(handles.pushbutton7,'position',[pos(1) pos(2) N1 N2])

% Set ToolTipString.
txt=['The GOES Imager downloads data every 15 minutes. ',...
    ' The data are mapped to an equal angle grid (0.05 degrees latitude  ',...
    ' by 0.05 degrees longitude) using a simple arithmetic mean to produce ',...
    ' composite images of various durations (e.g., 1, 3, 8 day).',... 
    ' 1,3,8,14 day running averages are calculated for each day,'...
    ' 1month average is calculated once per month.'...
    ' Note that the time corresponds to the end of the averaging period.'];
op_tooltipwrap(handles.text4,txt,38);

if get(handles.checkbox1,'Value')==0 
set(handles.checkbox1,'Value',1)
end

if get(handles.radiobutton1,'Value')==0 & get(handles.radiobutton2,'Value')==0
set(handles.radiobutton1,'Value',1)
end

if get(handles.radiobutton2,'Value') == 0
    set(handles.edit14,'BackgroundColor',[0.8 0.8 0.8],'Enable','Off')
    set(handles.edit15,'BackgroundColor',[0.8 0.8 0.8],'Enable','Off')
elseif get(handles.radiobutton2,'Value') == 1
    set(handles.edit14,'BackgroundColor',[1. 1. 1.],'Enable','On')
    set(handles.edit15,'BackgroundColor',[1. 1. 1.],'Enable','On')
end

% Make 'Load Last Request' button inactive when file gui_xxx_request.mat is
% absent.
if ~exist('gui_goes_request.mat','file') 
    set(handles.pushbutton5,'Enable','Off')
end

set(handles.pushbutton1,'String','Get Data','BackgroundColor',[0 1. 0.25])
%set(hObject,'Enable','On','String','Get Data','BackgroundColor',[0 1. 0.25]);

% Update handles "openfigure" field.
handles.openfigure = 1;

% Choose default command line output for gui_goes
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes gui_goes wait for user response (see UIRESUME)
% uiwait(handles.figure1);

% --- Outputs from this function are returned to the command line.
function varargout = gui_goes_OutputFcn(hObject, eventdata, handles)

% Get default command line output from handles structure
varargout{1} = handles.output;

function GetDataSetRanges(handles)

% Get available time range
S=get(handles.popupmenu1,'String');j=get(handles.popupmenu1,'Value');
TAVG=deblank(S{j});
if strcmp(TAVG,'1month'), TAVG='mday'; end
h=msgbox('Acquiring metadata from GOES site, please wait ...');
% next line makes OK button invisible
hh=get(h,'Children'); set(hh(2),'Visible','off'); pause(1);
loaddap('+v',['http://oceanwatch.pfeg.noaa.gov:8081/thredds/dodsC/satellite/GA/ssta/' TAVG '?time,lat,lon']);
close(h)
if ~exist('time','var')
  errordlg('Connection to host oceanwatch.pfeg.noaa.gov timed out. Please try again later')
  return
end

T1=datestr(datenum(1970,01,01)+time(1)/86400,'yyyy-mm-dd');
T2=datestr(datenum(1970,01,01)+time(end)/86400,'yyyy-mm-dd');
TRANGE=['Available time range: [' T1 ' to ' T2 ']'];
set(handles.text7,'String',TRANGE)

S=['Available latitude range: [' num2str(lat(1)) ' to ' num2str(lat(end)) ']'];
set(handles.text15,'String',S)
S=['Available longitude range: [' num2str(lon(1)) ' to ' num2str(lon(end)) ']'];
set(handles.text19,'String',S)

function checkbox1_Callback(hObject, eventdata, handles)

function edit1_CreateFcn(hObject, eventdata, handles)
function edit1_Callback(hObject, eventdata, handles)
function edit2_CreateFcn(hObject, eventdata, handles)
function edit2_Callback(hObject, eventdata, handles)
function edit3_CreateFcn(hObject, eventdata, handles)
function edit3_Callback(hObject, eventdata, handles)
function edit4_CreateFcn(hObject, eventdata, handles)
function edit4_Callback(hObject, eventdata, handles)
function edit5_CreateFcn(hObject, eventdata, handles)
function edit5_Callback(hObject, eventdata, handles)
function edit6_CreateFcn(hObject, eventdata, handles)
function edit6_Callback(hObject, eventdata, handles)
function edit7_CreateFcn(hObject, eventdata, handles)
function edit7_Callback(hObject, eventdata, handles)
function edit8_CreateFcn(hObject, eventdata, handles)
function edit8_Callback(hObject, eventdata, handles)
function edit9_CreateFcn(hObject, eventdata, handles)
function edit9_Callback(hObject, eventdata, handles)
function edit10_CreateFcn(hObject, eventdata, handles)
function edit10_Callback(hObject, eventdata, handles)
function edit11_CreateFcn(hObject, eventdata, handles)
function edit11_Callback(hObject, eventdata, handles)
function edit12_CreateFcn(hObject, eventdata, handles)
function edit12_Callback(hObject, eventdata, handles)
function edit13_CreateFcn(hObject, eventdata, handles)
function edit13_Callback(hObject, eventdata, handles)
function edit14_CreateFcn(hObject, eventdata, handles)
function edit14_Callback(hObject, eventdata, handles)
function edit15_CreateFcn(hObject, eventdata, handles)
function edit15_Callback(hObject, eventdata, handles)

function popupmenu1_CreateFcn(hObject, eventdata, handles)
function popupmenu1_Callback(hObject, eventdata, handles)
% get the range of available times
S=get(handles.popupmenu1,'String');j=get(handles.popupmenu1,'Value');
TAVG=deblank(S{j});
if strcmp(TAVG,'1month') TAVG='mday'; end
loaddap(['http://oceanwatch.pfeg.noaa.gov:8081/thredds/dodsC/satellite/GA/ssta/' TAVG '?time']);
T1=datestr(datenum(1970,01,01)+time(1)/86400,'yyyy-mm-dd');
T2=datestr(datenum(1970,01,01)+time(end)/86400,'yyyy-mm-dd');
TRANGE=['Available time range: [' T1 ' to ' T2 ']'];
set(handles.text7,'String',TRANGE)

function radiobutton1_Callback(hObject, eventdata, handles)
function radiobutton2_Callback(hObject, eventdata, handles)
if get(handles.radiobutton2,'Value') == 0
    set(handles.edit14,'BackgroundColor',[0.8 0.8 0.8],'Enable','Off')
    set(handles.edit15,'BackgroundColor',[0.8 0.8 0.8],'Enable','Off')
elseif get(handles.radiobutton2,'Value') == 1
    set(handles.edit14,'BackgroundColor',[1. 1. 1.],'Enable','On')
    set(handles.edit15,'BackgroundColor',[1. 1. 1.],'Enable','On')
end

function popupmenu2_Callback(hObject, eventdata, handles)
function popupmenu2_CreateFcn(hObject, eventdata, handles)

function pushbutton2_Callback(hObject, eventdata, handles)
if get(handles.radiobutton2,'Value') == 1
DIRNAME=uigetdir(pwd,'Select a Directory for Downloading Files');
set(handles.edit14,'String',DIRNAME)
end

% The main button that starts data acquisition
function pushbutton1_Callback(hObject, eventdata, handles)
% uiresume(handles.figure1)

% Turn off ability to re-issue "Get Data."
set(hObject,'BackgroundColor',[0.8 0.8 0.8],'Enable','Off','String','Please wait...');
pause(.1)

% Get input from user.
request=InputGet(hObject, eventdata, handles);

% Save request to .mat file.
filename = 'gui_goes_request.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname)-length(mfilename)); %mfilename does not have .m in it
    filename = [pname,filename];
end
save(filename,'request','-mat')
set(handles.pushbutton5,'Enable','On')

% If it passes inspection, send down to user's workspace
% as variable "request". Then the user can get the data
% assignin('base','request',request);

% Get data.
get_goes(request);

% Re-enable button after obtaining data.
set(hObject,'Enable','On','String','Get Data','BackgroundColor',[0 1. 0.25])

function pushbutton3_Callback(hObject, eventdata, handles)
web 'http://coastwatch.pfeg.noaa.gov/infog/GA_ssta_las.html' -browser
function pushbutton6_Callback(hObject, eventdata, handles)
%web 'http://www.nasa.gov/topics/earth/index.html' -browser
web 'http://www.nasa.gov' -browser
function pushbutton4_Callback(hObject, eventdata, handles)
web 'http://www.opendap.org/' -browser

function request=InputGet(hObject, eventdata, handles)
S1=deblank(get(handles.edit1,'String'));
S2=deblank(get(handles.edit2,'String'));
S3=deblank(get(handles.edit3,'String'));
S4=deblank(get(handles.edit4,'String'));
S5=deblank(get(handles.edit5,'String'));
S6=deblank(get(handles.edit6,'String'));

R.DATE1='00000000';
R.DATE1(4-length(S1)+1:4)=S1;
R.DATE1(6-length(S2)+1:6)=S2;
R.DATE1(8-length(S3)+1:8)=S3;
R.DATE2='00000000';
R.DATE2(4-length(S4)+1:4)=S4;
R.DATE2(6-length(S5)+1:6)=S5;
R.DATE2(8-length(S6)+1:8)=S6;

R.DATEINCR=str2num(deblank(get(handles.edit11,'String')));

R.LAT1=str2num(deblank(get(handles.edit7,'String')));
R.LAT2=str2num(deblank(get(handles.edit8,'String')));
R.LON1=str2num(deblank(get(handles.edit9,'String')));
R.LON2=str2num(deblank(get(handles.edit10,'String')));
R.LATINCR=str2num(deblank(get(handles.edit12,'String')));
R.LONINCR=str2num(deblank(get(handles.edit13,'String')));

S=get(handles.popupmenu1,'String');j=get(handles.popupmenu1,'Value');
R.TAVG=deblank(S{j});
if strcmp(R.TAVG,'1month') R.TAVG='mday'; end

R.Fields={'sst','y'};

R.DIRNAME=deblank(get(handles.edit14,'String'));
if isempty(R.DIRNAME) R.DIRNAME=''; end
R.FNPREFIX=deblank(get(handles.edit15,'String'));

R.SaveWorkspace='n'; 
if get(handles.radiobutton1,'Value') == 1 R.SaveWorkspace='y'; end
R.SaveFiles='n'; 
if get(handles.radiobutton2,'Value') == 1 R.SaveFiles='y'; end

S=get(handles.popupmenu2,'String');j=get(handles.popupmenu2,'Value');
R.SaveMode=deblank(S{j});

request=R;

% Get default command line output from handles structure
handles.request=request;

% Load Last request
function pushbutton5_Callback(hObject, eventdata, handles)
filename = 'gui_goes_request.mat';
if exist(filename,'file')
    load(filename)
else
    msgbox(['File ',filename,' does not exist.']);
    return
end

R=request;

% select only checked variables
[L1,L2]=size(R.Fields);
for k=1:L1
    eval(['set(handles.checkbox' num2str(k) ',''Value'',0)'])
    if R.Fields{k,2}=='y';
        eval(['set(handles.checkbox' num2str(k) ',''Value'',1)']) 
    end
end

% get strings from GUI menu and convert them to numbers
set(handles.edit1,'String',R.DATE1(1:4));
set(handles.edit2,'String',R.DATE1(5:6)); 
set(handles.edit3,'String',R.DATE1(7:8)); 
set(handles.edit4,'String',R.DATE2(1:4));
set(handles.edit5,'String',R.DATE2(5:6)); 
set(handles.edit6,'String',R.DATE2(7:8)); 
set(handles.edit7,'String',num2str(R.LAT1));
set(handles.edit8,'String',num2str(R.LAT2));
set(handles.edit9,'String',num2str(R.LON1));
set(handles.edit10,'String',num2str(R.LON2));
set(handles.edit11,'String',num2str(R.DATEINCR));
set(handles.edit12,'String',num2str(R.LATINCR));
set(handles.edit13,'String',num2str(R.LONINCR));
set(handles.edit14,'String',R.DIRNAME);
set(handles.edit15,'String',R.FNPREFIX);

S=get(handles.popupmenu1,'String');
TAVG1=R.TAVG;if strcmp(R.TAVG,'mday') TAVG1='1month'; end
j=find(strcmp(S,TAVG1));
set(handles.popupmenu1,'Value',j);

set(handles.radiobutton1,'Value',0);
if R.SaveWorkspace=='y'  set(handles.radiobutton1,'Value',1); end
set(handles.radiobutton2,'Value',0);
if R.SaveFiles=='y'  set(handles.radiobutton2,'Value',1); end

S=get(handles.popupmenu2,'String');
j=find(strcmp(S,R.SaveMode));
if isempty(j) j=1; end
set(handles.popupmenu2,'Value',j);

SaveFilesOnOff(hObject, eventdata, handles)

function SaveFilesOnOff(hObject, eventdata, handles)   
if get(handles.radiobutton2,'Value') == 0
    set(handles.edit14,'BackgroundColor',[0.8 0.8 0.8],'Enable','Off')
    set(handles.edit15,'BackgroundColor',[0.8 0.8 0.8],'Enable','Off')
elseif get(handles.radiobutton2,'Value') == 1
    set(handles.edit14,'BackgroundColor',[1. 1. 1.],'Enable','On')
    set(handles.edit15,'BackgroundColor',[1. 1. 1.],'Enable','On')
end


function pushbutton7_Callback(hObject, eventdata, handles)
h = op_timemessage('goes',0);

