function dsi_oaflux(varargin)
% updates the DataSetInventory structures
% without arguments for all the following DataSetBranches

if nargin < 1
%DSI_OAFlux
DataSetBranchList={
'OAFlux_daily';
'OAFlux_monthly';
};

if ~exist('dsi_oaflux.mat','file')
save dsi_oaflux.mat DataSetBranchList
end
save dsi_oaflux.mat -append DataSetBranchList

for k=1:length(DataSetBranchList)    
eval(['DSI_' DataSetBranchList{k} ';'])
end

elseif nargin > 1
disp('Incorrect number of arguments.'); return
else
% with one argument for the specified DataSetBranch only
eval(varargin{1});
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function DSI=DSI_OAFlux_daily
% create DataSetInventory of OAFlux

% Example of loaddap argument
%http://apdrc.soest.hawaii.edu/thredds/dodsC/whoi/oaflux/daily?
%time[0:1:7304],lat[0:1:179],lon[0:1:359],nlwrs[0:1:7304][0:1:179][0:1:359]
DSI.DataSetBranch='OAFlux_daily';

% a general request employed by get_DataSet program has the following pattern
% loaddap([URLSITE URLPATH URLFILE '?' URLCVAR URLCTIME URLCLAT URLCLON])
%   constraints URLCTIME URLCLAT URLCLON can be in different order
%   constraints URLCTIME URLCLAT URLCLON will be generated by program get

%http://apdrc.soest.hawaii.edu/thredds/dodsC/whoi/oaflux/daily?
%nlwrs[0:1:7304][0:1:179][0:1:359]
DSI.URLSITE='http://apdrc.soest.hawaii.edu';
DSI.URLPATH='/thredds/dodsC/whoi/oaflux/';
DSI.URLFILE='daily';
URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE];

%A=loaddap('-A','http://apdrc.soest.hawaii.edu/thredds/dodsC/whoi/oaflux/daily')
%A = 
%                 time: [1x1 struct]
%                  lat: [1x1 struct]
%                  lon: [1x1 struct]
%                nlwrs: [1x1 struct]
%                nswrs: [1x1 struct]
%                 qnet: [1x1 struct]
%                evapr: [1x1 struct]
%                  err: [1x1 struct]
%                hum2m: [1x1 struct]
%                shtfl: [1x1 struct]
%                tmp2m: [1x1 struct]
%                tmpsf: [1x1 struct]
%                wnd10: [1x1 struct]
%    Global_Attributes: [1x1 struct]

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','lat','lon'};
DSI.Fields={
% opendap name, dataset name,    menu name,                                 long name,      
    'nlwrs'      ,'nlwrs'      ,'net longwave radiation flux (nlwrs)'      ,'net surface longwave radiation flux (positive upward) [w/m/m]'   ,2 ,LL ,3 ,TLL ,1;
    'nswrs'      ,'nswrs'      ,'net shortwave radiation flux (nswrs)'     ,'net surface shortwave radiation flux (positive downward) [w/m/m]',2 ,LL ,3 ,TLL ,2;
    'qnet'       ,'qnet'       ,'net surface heat flux (qnet)'             ,'net surface heat flux (positive down) [w/m/m]'                   ,2 ,LL ,3 ,TLL ,3;
    'evapr'      ,'evapr'      ,'evaporation rate (evapr)'                 ,'daily mean evaporation rate [cm/yr]'                             ,2 ,LL ,3 ,TLL ,4; 
    'err'        ,'err'        ,'estimated error of evaporation rate (err)','daily mean estimated error of evaporation rate [cm/yr]'          ,2 ,LL ,3 ,TLL ,5;
    'hum2m'      ,'hum2m'      ,'specific humidity at 2m (hum2m)'          ,'daily mean specific humidity at 2m [g/kg]'                       ,2 ,LL ,3 ,TLL ,6;
    'shtfl'      ,'shtfl'      ,'sensible heat flux (shtfl)'               ,'daily mean surface sensible heat flux, positive upward [w/m/m]'  ,2 ,LL ,3 ,TLL ,7;
    'tmp2m'      ,'tmp2m'      ,'air temperature at 2m ( tmp2m)'           ,'daily mean air temperature at 2m [degc]'                         ,2 ,LL ,3 ,TLL ,8;
    'tmpsf'      ,'tmpsf'      ,'sea surface temperature (tmpsf)'          ,'daily mean sea surface temperature [degc]'                       ,2 ,LL ,3 ,TLL ,9;
    'wnd10'      ,'wnd10'      ,'neutral wind speed at 10m (wnd10)'        ,'daily mean neutral wind speed at 10m [m/s]'                      ,2 ,LL ,3 ,TLL ,10;       
    };


DSI.Fields_NameDS  =DSI.Fields(:,2);
DSI.Fields_NameMenu=DSI.Fields(:,3);
DSI.Fields_NameLong=DSI.Fields(:,4);
DSI.Fields_Dim     =DSI.Fields(:,5);
DSI.Fields_Coord   =DSI.Fields(:,6);
DSI.Fields_DimDS   =DSI.Fields(:,7);
DSI.Fields_CoordDS =DSI.Fields(:,8);
DSI.Fields_CBNum   =DSI.Fields(:,9);

% missing_value: 1.0E20 % same for all fields
%DSI.FormulaNaN='f(find(f==1.0e20))=NaN;'; % does not work
DSI.FormulaNaN='f(find(f>0.9e20))=NaN;';

%grads_dim: "t"
%grads_mapping: "linear"
%grads_size: "7305"
%grads_min: "00z01jan1985"
%grads_step: "1440mn"
%units: "days since 1-1-1 00:00:0.0"
loaddap('+v',[URL '?time'])
t0=datenum('1985-01-01 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time-time(1)+t0; % in datenum
DSI.TimeA=t-0.5;
DSI.TimeB=t+0.5;
DSI.Time=t;

loaddap('+v',[URL '?lat'])
DSI.Latitude=lat;
loaddap('+v',[URL '?lon'])
DSI.Longitude=lon';

%DSI.Range.Time1=min(DSI.TimeA);
%DSI.Range.Time2=max(DSI.TimeB);
DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);
DSI.Range.TRes='daily';
DSI.Range.HRes='1 deg';

S1=['time in seconds since reference_time;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];

eval(['DSI_' DSI.DataSetBranch '=DSI;'])
if ~exist('dsi_oaflux.mat','file')
eval(['save dsi_oaflux.mat DSI_' DSI.DataSetBranch ';'])
end
eval(['save dsi_oaflux.mat -append DSI_' DSI.DataSetBranch ';'])
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function DSI=DSI_OAFlux_monthly
% create DataSetInventory of OAFlux

% Example of loaddap argument
%http://apdrc.soest.hawaii.edu/thredds/dodsC/whoi/oaflux/monthly?
%time[0:1:587],lat[0:1:179],lon[0:1:359],nlwrs[0:1:0][0:1:0][0:1:0]
DSI.DataSetBranch='OAFlux_monthly';

% a general request employed by get_DataSet program has the following pattern
% loaddap([URLSITE URLPATH URLFILE '?' URLCVAR URLCTIME URLCLAT URLCLON])
%   constraints URLCTIME URLCLAT URLCLON can be in different order
%   constraints URLCTIME URLCLAT URLCLON will be generated by program get

%http://apdrc.soest.hawaii.edu/thredds/dodsC/whoi/oaflux/monthly?
%nlwrs[0:1:7304][0:1:179][0:1:359]
DSI.URLSITE='http://apdrc.soest.hawaii.edu';
DSI.URLPATH='/thredds/dodsC/whoi/oaflux/';
DSI.URLFILE='monthly';
URL=[DSI.URLSITE DSI.URLPATH DSI.URLFILE];

%A=loaddap('-A','http://apdrc.soest.hawaii.edu/thredds/dodsC/whoi/oaflux/daily')
%A = 
%                 time: [1x1 struct]
%                  lat: [1x1 struct]
%                  lon: [1x1 struct]
%                nlwrs: [1x1 struct]
%                nswrs: [1x1 struct]
%                 qnet: [1x1 struct]
%                evapr: [1x1 struct]
%                  err: [1x1 struct]
%                hum2m: [1x1 struct]
%                shtfl: [1x1 struct]
%                tmp2m: [1x1 struct]
%                tmpsf: [1x1 struct]
%                wnd10: [1x1 struct]
%    Global_Attributes: [1x1 struct]

% define list of fields or variables available in the dataset
LL={'latitude','longitude'};
TLL={'time','lat','lon'};
DSI.Fields={
% opendap name, dataset name,    menu name,                                 long name,      
    'nlwrs'      ,'nlwrs'      ,'net longwave radiation flux (nlwrs)'      ,'net surface longwave radiation flux (positive upward) [w/m/m]'   ,2 ,LL ,3 ,TLL ,1;
    'nswrs'      ,'nswrs'      ,'net shortwave radiation flux (nswrs)'     ,'net surface shortwave radiation flux (positive downward) [w/m/m]',2 ,LL ,3 ,TLL ,2;
    'qnet'       ,'qnet'       ,'net surface heat flux (qnet)'             ,'net surface heat flux (positive down) [w/m/m]'                   ,2 ,LL ,3 ,TLL ,3;
    'evapr'      ,'evapr'      ,'evaporation rate (evapr)'                 ,'monthly mean evaporation rate [cm/yr]'                           ,2 ,LL ,3 ,TLL ,4; 
    'err'        ,'err'        ,'estimated error of evaporation rate (err)','monthly mean estimated error of evaporation rate [cm/yr]'        ,2 ,LL ,3 ,TLL ,5;
    'hum2m'      ,'hum2m'      ,'specific humidity at 2m (hum2m)'          ,'monthly mean specific humidity at 2m [g/kg]'                     ,2 ,LL ,3 ,TLL ,6;
    'shtfl'      ,'shtfl'      ,'sensible heat flux (shtfl)'               ,'monthly mean surface sensible heat flux, positive upward [w/m/m]',2 ,LL ,3 ,TLL ,7;
    'tmp2m'      ,'tmp2m'      ,'air temperature at 2m ( tmp2m)'           ,'monthly mean air temperature at 2m [degc]'                       ,2 ,LL ,3 ,TLL ,8;
    'tmpsf'      ,'tmpsf'      ,'sea surface temperature (tmpsf)'          ,'monthly mean sea surface temperature [degc]'                     ,2 ,LL ,3 ,TLL ,9;
    'wnd10'      ,'wnd10'      ,'neutral wind speed at 10m (wnd10)'        ,'monthly mean neutral wind speed at 10m [m/s]'                    ,2 ,LL ,3 ,TLL ,10;       
};
DSI.Fields_NameDS  =DSI.Fields(:,2);
DSI.Fields_NameMenu=DSI.Fields(:,3);
DSI.Fields_NameLong=DSI.Fields(:,4);
DSI.Fields_Dim     =DSI.Fields(:,5);
DSI.Fields_Coord   =DSI.Fields(:,6);
DSI.Fields_DimDS   =DSI.Fields(:,7);
DSI.Fields_CoordDS =DSI.Fields(:,8);
DSI.Fields_CBNum   =DSI.Fields(:,9);

% missing_value: 1.0E20 % same for all fields
%DSI.FormulaNaN='f(find(f==1.0e20))=NaN;'; % does not work
DSI.FormulaNaN='f(find(f>0.9e20))=NaN;';


%grads_dim: "t"
%grads_mapping: "linear"
%grads_size: "588"
%grads_min: "00z15jan1958"
%grads_step: "1mo"
%units: "days since 1-1-1 00:00:0.0"
loaddap('+v',[URL '?time'])
t0=datenum('1958-01-15 00:00:00','yyyy-mm-dd HH:MM:SS'); 
t=time-time(1)+t0; % in datenum
DSI.TimeA=t-15;
DSI.TimeB=t+15;
DSI.Time=t;

loaddap('+v',[URL '?lat'])
DSI.Latitude=lat;
loaddap('+v',[URL '?lon'])
DSI.Longitude=lon';

%DSI.Range.Time1=min(DSI.TimeA);
%DSI.Range.Time2=max(DSI.TimeB);
DSI.Range.Time1=min(DSI.Time);
DSI.Range.Time2=max(DSI.Time);
DSI.Range.Latitude1=min(DSI.Latitude);
DSI.Range.Latitude2=max(DSI.Latitude);
DSI.Range.Longitude1=min(DSI.Longitude);
DSI.Range.Longitude2=max(DSI.Longitude);
DSI.Range.TRes='monthly';
DSI.Range.HRes='1 deg';

S1=['time in seconds since reference_time;'];
S2=['missing values replaced with NaN;'];
S3=['variables converted to physical units.'];
%DSI.Readme=[S1 '/' S2 '/' S3];
DSI.Readme=[S1 '/' S2];


eval(['DSI_' DSI.DataSetBranch '=DSI;'])
if ~exist('dsi_oaflux.mat','file')
eval(['save dsi_oaflux.mat DSI_' DSI.DataSetBranch ';'])
end
eval(['save dsi_oaflux.mat -append DSI_' DSI.DataSetBranch ';'])
