function varargout = gui_oaflux(varargin)
% Boots-up OAFlux GUI, interacts with user via interface.
% gui_oaflux M-file for gui_oaflux.fig
%
% INPUT(S):
%
%   [none]
%
% OUTPUT(S):
%
%   h -- (optional) GUI handle
%
% OPeNDAP Science Team
% Copyright 2007, 2008
% $Version 2.0.0$

%==========================================================================
% Meri Sheremet
% June 2007
%
% REVISION HISTORY:
% 2007/06/01 created, ms
% 2008/06/15 modified for compiled version, ceb
%==========================================================================

warning('off','MATLAB:dispatcher:InexactMatch');
% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @gui_oaflux_OpeningFcn, ...
                   'gui_OutputFcn',  @gui_oaflux_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT
warning('on','MATLAB:dispatcher:InexactMatch');

% --- Executes just before gui_oaflux is made visible.
function gui_oaflux_OpeningFcn(hObject, eventdata, handles, varargin)

% Define handles "openfigure" field.
if ~isfield(handles,'openfigure')
    handles.openfigure = 0; %set equal to zero on the first time.
end

% Set interface name.
filename = 'get_oaflux';
txt = ['NASA/REASoN Ocean Data Portal - '];
tmp1 = ['OAFlux GUI'];
tmp2 = '';
txt = [txt,tmp1];
if (~isdeployed)
    tmp2 = strrep(op_version('mfile',filename),'Version ','');
    txt = [txt,' (Ver ',tmp2,')'];
end
set(hObject,'Name',txt);

%Place logos on the GUI    
% determine screen resolution and size of character in pixels
Units0=get(0,'Units'); % save initial settings
set(0,'Units','characters');
SSC=get(0,'ScreenSize'); % screen size in characters
set(0,'Units','pixels');
SSP=get(0,'ScreenSize'); % screen size in pixels
set(0,'Units',Units0); % restore to original units
ppcx=SSP(3)/SSC(3); % pixels per character along x
ppcy=SSP(4)/SSC(4); % pixels per character along y

[img,MAP]=imread('logo_opendap.jpg');
[NY,NX,N3]=size(img);
CX=(NX+8)/ppcx;         % button size in characters including 4 pixel grace margin
CY=(NY+12)/ppcy;
set(handles.pushbutton6,'CData',img)
pos = get(handles.pushbutton6,'position'); %units will be in characters
set(handles.pushbutton6,'position',[pos(1),pos(2),CX,CY]);

[img,MAP]=imread('logo_nasa1.jpg');
[NY,NX,N3]=size(img);
CX=(NX+8)/ppcx;         % button size in characters including 4 pixel grace margin
CY=(NY+12)/ppcy;
set(handles.pushbutton7,'CData',img)
pos = get(handles.pushbutton7,'position'); %units will be in characters
set(handles.pushbutton7,'position',[pos(1),pos(2),CX,CY]);  

[img,MAP]=imread('logo_whoi.jpg');
[NY,NX,N3]=size(img);
CX=(NX+8)/ppcx;         % button size in characters including 4 pixel grace margin
CY=(NY+12)/ppcy;
set(handles.pushbutton3,'CData',img)
pos = get(handles.pushbutton3,'position'); %units will be in characters
set(handles.pushbutton3,'position',[pos(1),pos(2),CX,CY]);

[img,MAP]=imread('logo_apdrc.jpg');
[NY,NX,N3]=size(img);
CX=(NX+8)/ppcx;         % button size in characters including 4 pixel grace margin
CY=(NY+12)/ppcy;
set(handles.pushbutton4,'CData',img)
pos = get(handles.pushbutton4,'position'); %units will be in characters
set(handles.pushbutton4,'position',[pos(1),pos(2),CX,CY]);

set(handles.edit15,'String',num2str(1));
set(handles.edit11,'String',num2str(1));
set(handles.edit12,'String',num2str(1));

if get(handles.radiobutton1,'Value')==0 & get(handles.radiobutton2,'Value')==0
    set(handles.radiobutton1,'Value',1)
end

% Make 'Load Last Request' button inactive when file gui_xxx_request.mat is
% absent.
if ~exist('gui_oaflux_request.mat','file') 
    set(handles.pushbutton5,'Enable','Off')
end

SaveFilesOnOff(hObject, eventdata, handles)
CheckRanges(hObject, eventdata, handles)

%set(handles.pushbutton1,'String','Get Data','BackgroundColor',[0 1. 0.25])
% Update handles "openfigure" field.
handles.openfigure = 1;
% Choose default command line output for gui_oaflux
handles.output = hObject;
% Update handles structure
guidata(hObject, handles);

% UIWAIT makes gui_oaflux wait for user response (see UIRESUME)
% uiwait(handles.figure1);

% --- Outputs from this function are returned to the command line.
function varargout = gui_oaflux_OutputFcn(hObject, eventdata, handles)

% Get default command line output from handles structure
varargout{1} = handles.output;

function checkbox1_Callback(hObject, eventdata, handles)
function checkbox2_Callback(hObject, eventdata, handles)
function checkbox3_Callback(hObject, eventdata, handles)
function checkbox4_Callback(hObject, eventdata, handles)
function checkbox5_Callback(hObject, eventdata, handles)
function checkbox6_Callback(hObject, eventdata, handles)
function checkbox7_Callback(hObject, eventdata, handles)
function checkbox8_Callback(hObject, eventdata, handles)
function checkbox9_Callback(hObject, eventdata, handles)
function checkbox10_Callback(hObject, eventdata, handles)

function edit1_Callback(hObject, eventdata, handles)
function edit1_CreateFcn(hObject, eventdata, handles)
function edit2_Callback(hObject, eventdata, handles)
function edit2_CreateFcn(hObject, eventdata, handles)
function edit3_Callback(hObject, eventdata, handles)
function edit3_CreateFcn(hObject, eventdata, handles)
function edit4_Callback(hObject, eventdata, handles)
function edit4_CreateFcn(hObject, eventdata, handles)
function edit5_Callback(hObject, eventdata, handles)
function edit5_CreateFcn(hObject, eventdata, handles)
function edit6_Callback(hObject, eventdata, handles)
function edit6_CreateFcn(hObject, eventdata, handles)
function edit7_Callback(hObject, eventdata, handles)
function edit7_CreateFcn(hObject, eventdata, handles)
function edit8_Callback(hObject, eventdata, handles)
function edit8_CreateFcn(hObject, eventdata, handles)
function edit9_Callback(hObject, eventdata, handles)
function edit9_CreateFcn(hObject, eventdata, handles)
function edit10_Callback(hObject, eventdata, handles)
function edit10_CreateFcn(hObject, eventdata, handles)
function edit11_Callback(hObject, eventdata, handles)
function edit11_CreateFcn(hObject, eventdata, handles)
function edit12_Callback(hObject, eventdata, handles)
function edit12_CreateFcn(hObject, eventdata, handles)
function edit13_Callback(hObject, eventdata, handles)
function edit13_CreateFcn(hObject, eventdata, handles)
function edit14_Callback(hObject, eventdata, handles)
function edit14_CreateFcn(hObject, eventdata, handles)
function edit15_Callback(hObject, eventdata, handles)
function edit15_CreateFcn(hObject, eventdata, handles)

function popupmenu1_Callback(hObject, eventdata, handles)
function popupmenu1_CreateFcn(hObject, eventdata, handles)

function popupmenu2_Callback(hObject, eventdata, handles)
CheckRanges(hObject, eventdata, handles)
function popupmenu2_CreateFcn(hObject, eventdata, handles)

function radiobutton1_Callback(hObject, eventdata, handles)
function radiobutton2_Callback(hObject, eventdata, handles)
SaveFilesOnOff(hObject, eventdata, handles)

function pushbutton2_Callback(hObject, eventdata, handles)
if get(handles.radiobutton2,'Value') == 1
DIRNAME=uigetdir(pwd,'Select a Directory for Downloading Files');
set(handles.edit13,'String',DIRNAME)
end

% The main button that starts data acquisition
function pushbutton1_Callback(hObject, eventdata, handles)
% uiresume(handles.figure1)
% Turn off ability to re-issue "Get Data."
set(hObject,'BackgroundColor',[0.8 0.8 0.8],'Enable','Off','String','Please wait...');
pause(.1)

% Get input from user.
request=InputGet(hObject, eventdata, handles);

% Save request to .mat file.
filename = 'gui_oaflux_request.mat';
if (~isdeployed)
    pname = mfilename('fullpath');
    pname = pname(1:length(pname)-length(mfilename)); %mfilename does not have .m in it
    filename = [pname,filename];
end
save(filename,'request','-mat')
set(handles.pushbutton5,'Enable','On')

% If it passes inspection, send down to user's workspace
% as variable "request". Then the user can get the data
% assignin('base','request',request);

get_oaflux(request);

set(hObject,'Enable','On','String','Get Data','BackgroundColor',[0 1. 0.25]);

function pushbutton3_Callback(hObject, eventdata, handles)
web('http://oaflux.whoi.edu/','-browser');
%web('http://apdrc.soest.hawaii.edu/datadoc/whoi_oaswlw.htm','-browser');
function pushbutton4_Callback(hObject, eventdata, handles)
web 'http://apdrc.soest.hawaii.edu/w_data/alldata3.htm' -browser
%web 'http://apdrc.soest.hawaii.edu/dods/public_data/WHOI_OAFlux' -browser  
function pushbutton6_Callback(hObject, eventdata, handles)
web 'http://www.opendap.org/' -browser
function pushbutton7_Callback(hObject, eventdata, handles)
%web 'http://www.nasa.gov/topics/earth/index.html' -browser
web 'http://www.nasa.gov' -browser

function request=InputGet(hObject, eventdata, handles)
DSI=LoadDSI(hObject, eventdata, handles);
R.Fields=DSI.Fields;
R.Fields(:,end+1)={'n'}; % add one more column to indicated checked fields
[NV,N2]=size(R.Fields);
% select only checked variables
for k=1:NV
CBNUM=num2str(DSI.Fields_CBNum{k});
    if eval(['get(handles.checkbox' CBNUM ',''Value'')']) == 1
    R.Fields{k,end}='y';    
    end
end

S=get(handles.popupmenu2,'String');j=get(handles.popupmenu2,'Value');
R.TAVG=deblank(S{j});
R.DataSetBranch=DSI.DataSetBranch;

R.DATE1='00000000';
S=deblank(get(handles.edit1,'String'));R.DATE1(4-length(S)+1:4)=S;
S=deblank(get(handles.edit2,'String'));R.DATE1(6-length(S)+1:6)=S;
S=deblank(get(handles.edit3,'String'));R.DATE1(8-length(S)+1:8)=S;
R.DATE2='00000000';
S=deblank(get(handles.edit4,'String'));R.DATE2(4-length(S)+1:4)=S;
S=deblank(get(handles.edit5,'String'));R.DATE2(6-length(S)+1:6)=S;
S=deblank(get(handles.edit6,'String'));R.DATE2(8-length(S)+1:8)=S;
R.DATEINCR=str2num(deblank(get(handles.edit15,'String')));

% make sure that both dataset requests have same time coverage 
%if (R.Fields{1,2}=='y' | R.Fields{2,2}=='y') & str2num(R.DATE1)<19830701
%    R.DATE1='19830701';
%end

R.LAT1=str2num(deblank(get(handles.edit7,'String')));
R.LAT2=str2num(deblank(get(handles.edit8,'String')));
R.LON1=str2num(deblank(get(handles.edit9,'String')));
R.LON2=str2num(deblank(get(handles.edit10,'String')));
R.LATINCR=str2num(deblank(get(handles.edit11,'String')));
R.LONINCR=str2num(deblank(get(handles.edit12,'String')));

R.SaveWorkspace='n'; 
if get(handles.radiobutton1,'Value') == 1 R.SaveWorkspace='y'; end
S=get(handles.popupmenu1,'String');j=get(handles.popupmenu1,'Value');
R.SaveMode=deblank(S{j});
R.SaveFiles='n'; 
if get(handles.radiobutton2,'Value') == 1 R.SaveFiles='y'; end
R.DIRNAME =deblank(get(handles.edit13,'String'));
if isempty(R.DIRNAME) R.DIRNAME=''; end
R.FNPREFIX=deblank(get(handles.edit14,'String'));

%R.RequestDate=datestr(now,'yyyy-mm-dd HH:MM:SS');
request=R;
handles.request=request;

% Load Last request
function pushbutton5_Callback(hObject, eventdata, handles)
filename = 'gui_oaflux_request.mat';
if exist(filename,'file')
    load(filename)
else
    msgbox(['File ',filename,' does not exist.']);
    return
end

R=request;

DSI=LoadDSI(hObject, eventdata, handles);

% select only checked variables
[NV,N2]=size(R.Fields);
for k=1:NV
CBNUM=num2str(DSI.Fields_CBNum{k});
eval(['set(handles.checkbox' CBNUM ',''Value'',0)'])
    if R.Fields{k,end}=='y';
    eval(['set(handles.checkbox' CBNUM ',''Value'',1)']) 
    end
end

% get strings from GUI menu and convert them to numbers
set(handles.edit1,'String',R.DATE1(1:4));
set(handles.edit2,'String',R.DATE1(5:6)); 
set(handles.edit3,'String',R.DATE1(7:8)); 
set(handles.edit4,'String',R.DATE2(1:4));
set(handles.edit5,'String',R.DATE2(5:6)); 
set(handles.edit6,'String',R.DATE2(7:8)); 
set(handles.edit7,'String',num2str(R.LAT1));
set(handles.edit8,'String',num2str(R.LAT2));
set(handles.edit9,'String',num2str(R.LON1));
set(handles.edit10,'String',num2str(R.LON2));
set(handles.edit11,'String',num2str(R.LATINCR));
set(handles.edit12,'String',num2str(R.LONINCR));
set(handles.edit13,'String',R.DIRNAME);
set(handles.edit14,'String',R.FNPREFIX);
set(handles.edit15,'String',num2str(R.DATEINCR));

S=get(handles.popupmenu2,'String');
j=find(strcmp(S,R.TAVG)); if isempty(j) j=1; end
set(handles.popupmenu2,'Value',j);

set(handles.radiobutton1,'Value',0);
if R.SaveWorkspace=='y'
    set(handles.radiobutton1,'Value',1); 
end
S=get(handles.popupmenu1,'String');
j=find(strcmp(S,R.SaveMode)); if isempty(j) j=1; end
set(handles.popupmenu1,'Value',j);
set(handles.radiobutton2,'Value',0);
if R.SaveFiles=='y'
    set(handles.radiobutton2,'Value',1); 
end
SaveFilesOnOff(hObject, eventdata, handles)
CheckRanges(hObject, eventdata, handles)

function SaveFilesOnOff(hObject, eventdata, handles)   
if get(handles.radiobutton2,'Value') == 0
    set(handles.edit13,'BackgroundColor',[0.8 0.8 0.8],'Enable','Off')
    set(handles.edit14,'BackgroundColor',[0.8 0.8 0.8],'Enable','Off')
elseif get(handles.radiobutton2,'Value') == 1
    set(handles.edit13,'BackgroundColor',[1. 1. 1.],'Enable','On')
    set(handles.edit14,'BackgroundColor',[1. 1. 1.],'Enable','On')
end

function DSI=LoadDSI(hObject, eventdata, handles)
load dsi_oaflux.mat
%S=get(handles.popupmenu2,'String');
j=get(handles.popupmenu2,'Value');
eval(['DSI=DSI_' DataSetBranchList{j} ';'])
DSI.DataSetBranchList=DataSetBranchList;

function CheckRanges(hObject, eventdata, handles)
DSI=LoadDSI(hObject, eventdata, handles);
% make visible and active only checkboxes corresponding to existing variables
L=[1:1:10]; 
for k=1:length(L) % first make all field checkboxes invisible
CBNUM=num2str(L(k));
eval(['set(handles.checkbox' CBNUM ',''Visible'',''off'',''Enable'',''off'')'])
end
for k=1:length(DSI.Fields(:,1)) % make active only checked fields
    FIELDMENU=DSI.Fields_NameMenu{k};
    CBNUM=num2str(DSI.Fields_CBNum{k});
    eval(['set(handles.checkbox' CBNUM ',''Visible'',''on'',''Enable'',''on'',''String'',''' FIELDMENU ''')'])
end

set(handles.text14,'String',...
['Available time range: [' datestr(DSI.Range.Time1,'yyyy-mm-dd') ' to ' datestr(DSI.Range.Time2,'yyyy-mm-dd') ']'],'ForegroundColor',[0 0 1])
set(handles.text22,'String',...
['Available latitude range: [' num2str(DSI.Range.Latitude1) ' to ' num2str(DSI.Range.Latitude2) ']'],'ForegroundColor',[0 0 1])
set(handles.text26,'String',...
['Available longitude range: [' num2str(DSI.Range.Longitude1) ' to ' num2str(DSI.Range.Longitude2) ']'],'ForegroundColor',[0 0 1])
set(handles.text36,'String', ['Temporal resolution is ' DSI.Range.TRes],'ForegroundColor',[0 0 1])
set(handles.text6 ,'String', ['Spatial resolution is ' DSI.Range.HRes],'ForegroundColor',[0 0 1])

%
%S=get(handles.popupmenu1,'String');j=get(handles.popupmenu1,'Value');S=deblank(S{j});
%TXT=['Temporal resolution is ' S];
%set(handles.text39,'String',TXT,'ForegroundColor',[0 0 1])
%S=get(handles.popupmenu2,'String');j=get(handles.popupmenu2,'Value');S=deblank(S{j});
%TXT=['Spatial resolution is ' S];
%set(handles.text40,'String',TXT,'ForegroundColor',[0 0 1])

